"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkProxy(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkproxy.html

    **Detailed Description**

    QNetworkProxy provides the method for configuring network layer proxy
    support to the Qt network classes. The currently supported classes are
    **QAbstractSocket** , **QTcpSocket** , **QUdpSocket** , **QTcpServer**  and
    **QNetworkAccessManager** . The proxy support is designed to be as
    transparent as possible. This means that existing network-enabled
    applications that you have written should automatically support network
    proxy using the following code.

    **QNetworkProxy**  proxy;
        proxy.setType(**QNetworkProxy**
    ::Socks5Proxy);
        proxy.setHostName("proxy.example.com");
    proxy.setPort(1080);
        proxy.setUser("username");
    proxy.setPassword("password");
        **QNetworkProxy**
    ::setApplicationProxy(proxy);

    An alternative to setting an application wide proxy is to specify the proxy
    for individual sockets using **QAbstractSocket::setProxy** () and
    **QTcpServer::setProxy** (). In this way, it is possible to disable the use
    of a proxy for specific sockets using the following code:

    serverSocket->setProxy(**QNetworkProxy** ::NoProxy);

    Network proxy is not used if the address used in **connectToHost** (),
    **bind** () or **listen** () is equivalent to **QHostAddress::LocalHost**
    or **QHostAddress::LocalHostIPv6** .

    Each type of proxy support has certain restrictions associated with it. You
    should read the **ProxyType**  documentation carefully before selecting a
    proxy type to use.

    **Note:** Changes made to currently connected sockets do not take effect. If
    you need to change a connected socket, you should reconnect it.

    **SOCKS5**

    The SOCKS5 support since Qt 4 is based on **RFC 1928**  and **RFC 1929** .
    The supported authentication methods are no authentication and
    username/password authentication. Both IPv4 and IPv6 are supported. Domain
    names are resolved through the SOCKS5 server if the
    **QNetworkProxy::HostNameLookupCapability**  is enabled, otherwise they are
    resolved locally and the IP address is sent to the server. There are several
    things to remember when using SOCKS5 with **QUdpSocket**  and **QTcpServer**
    :

    With **QUdpSocket** , a call to **bind** () may fail with a timeout error.
    If a port number other than 0 is passed to **bind** (), it is not guaranteed
    that it is the specified port that will be used. Use **localPort** () and
    **localAddress** () to get the actual address and port number in use.
    Because proxied UDP goes through two UDP connections, it is more likely that
    packets will be dropped.

    With **QTcpServer**  a call to **listen** () may fail with a timeout error.
    If a port number other than 0 is passed to **listen** (), then it is not
    guaranteed that it is the specified port that will be used. Use
    **serverPort** () and **serverAddress** () to get the actual address and
    port used to listen for connections. SOCKS5 only supports one accepted
    connection per call to **listen** (), and each call is likely to result in a
    different **serverPort** () being used.

    **See also** **QAbstractSocket**  and **QTcpServer** .
    """

    class Capability(enum.Flag):
        TunnelingCapability: QNetworkProxy = ...
        ListeningCapability: QNetworkProxy = ...
        UdpTunnelingCapability: QNetworkProxy = ...
        CachingCapability: QNetworkProxy = ...
        HostNameLookupCapability: QNetworkProxy = ...
        SctpTunnelingCapability: QNetworkProxy = ...
        SctpListeningCapability: QNetworkProxy = ...

    class ProxyType(enum.Enum):
        DefaultProxy: QNetworkProxy = ...
        Socks5Proxy: QNetworkProxy = ...
        NoProxy: QNetworkProxy = ...
        HttpProxy: QNetworkProxy = ...
        HttpCachingProxy: QNetworkProxy = ...
        FtpCachingProxy: QNetworkProxy = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#QNetworkProxy

        **QNetworkProxy::QNetworkProxy()**

        Constructs a QNetworkProxy with **DefaultProxy**  type.

        The proxy type is determined by **applicationProxy** (), which defaults
        to **NoProxy**  or a system-wide proxy if one is configured.

        **See also** **setType** () and **setApplicationProxy** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        type: "QNetworkProxy.ProxyType",
        hostName: str = ...,
        port: int = ...,
        user: str = ...,
        password: str = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#QNetworkProxy-1

        **QNetworkProxy::QNetworkProxy(QNetworkProxy::ProxyType type , const
        QString & hostName = QString(), quint16 port = 0, const QString & user =
        QString(), const QString & password = QString())**

        Constructs a QNetworkProxy with **type** , **hostName** , **port** ,
        **user** and **password**.

        The default capabilities for proxy type **type** are set automatically.

        **See also** **capabilities** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkProxy") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#QNetworkProxy-2

        **QNetworkProxy::QNetworkProxy(const QNetworkProxy & other )**

        Constructs a copy of **other**.
        """
        ...

    def setRawHeader(
        self, headerName: QtCore.QByteArray, value: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setRawHeader

        **[since 5.0] void QNetworkProxy::setRawHeader(const QByteArray &
        headerName , const QByteArray & headerValue )**

        Sets the header **headerName** to be of value **headerValue**. If
        **headerName** corresponds to a known header (see
        **QNetworkRequest::KnownHeaders** ), the raw format will be parsed and
        the corresponding "cooked" header will be set as well.

        For example:

        request.setRawHeader(**QByteArray** ("Last-Modified"), **QByteArray**
        ("Sun, 06 Nov 1994 08:49:37 GMT"));

        will also set the known header LastModifiedHeader to be the
        **QDateTime**  object of the parsed date.

        **Note:** Setting the same header twice overrides the previous setting.
        To accomplish the behaviour of multiple HTTP headers of the same name,
        you should concatenate the two values, separating them with a comma
        (",") and set one single raw header.

        If the proxy is not of type **HttpProxy**  or **HttpCachingProxy**  this
        has no effect.

        This function was introduced in Qt 5.0.

        **See also** **QNetworkRequest::KnownHeaders** , **setHeader** (),
        **hasRawHeader** (), and **rawHeader** ().
        """
        ...

    def rawHeader(self, headerName: QtCore.QByteArray) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#rawHeader

        **[since 5.0] QByteArray QNetworkProxy::rawHeader(const QByteArray &
        headerName ) const**

        Returns the raw form of header **headerName**. If no such header is
        present or the proxy is not of type **HttpProxy**  or
        **HttpCachingProxy** , an empty **QByteArray**  is returned, which may
        be indistinguishable from a header that is present but has no content
        (use **hasRawHeader** () to find out if the header exists or not).

        Raw headers can be set with **setRawHeader** () or with **setHeader**
        ().

        This function was introduced in Qt 5.0.

        **See also** **header** () and **setRawHeader** ().
        """
        ...

    def rawHeaderList(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#rawHeaderList

        **[since 5.0] QList<QByteArray> QNetworkProxy::rawHeaderList() const**

        Returns a list of all raw headers that are set in this network proxy.
        The list is in the order that the headers were set.

        If the proxy is not of type **HttpProxy**  or **HttpCachingProxy**  an
        empty **QList**  is returned.

        This function was introduced in Qt 5.0.

        **See also** **hasRawHeader** () and **rawHeader** ().
        """
        ...

    def hasRawHeader(self, headerName: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#hasRawHeader

        **[since 5.0] bool QNetworkProxy::hasRawHeader(const QByteArray &
        headerName ) const**

        Returns `true` if the raw header **headerName** is in use for this
        proxy. Returns `false` if the proxy is not of type **HttpProxy**  or
        **HttpCachingProxy** .

        This function was introduced in Qt 5.0.

        **See also** **rawHeader** () and **setRawHeader** ().
        """
        ...

    def setHeader(
        self, header: "QNetworkRequest.KnownHeaders", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setHeader

        **[since 5.0] void
        QNetworkProxy::setHeader(QNetworkRequest::KnownHeaders header , const
        QVariant & value )**

        Sets the value of the known header **header** to be **value** ,
        overriding any previously set headers. This operation also sets the
        equivalent raw HTTP header.

        If the proxy is not of type **HttpProxy**  or **HttpCachingProxy**  this
        has no effect.

        This function was introduced in Qt 5.0.

        **See also** **QNetworkRequest::KnownHeaders** , **setRawHeader** (),
        and **header** ().
        """
        ...

    def header(self, header: "QNetworkRequest.KnownHeaders") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#header

        **[since 5.0] QVariant
        QNetworkProxy::header(QNetworkRequest::KnownHeaders header ) const**

        Returns the value of the known network header **header** if it is in use
        for this proxy. If it is not present, returns QVariant() (i.e., an
        invalid variant).

        This function was introduced in Qt 5.0.

        **See also** **QNetworkRequest::KnownHeaders** , **rawHeader** (), and
        **setHeader** ().
        """
        ...

    def swap(self, other: "QNetworkProxy") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#swap

        **[since 5.0] void QNetworkProxy::swap(QNetworkProxy & other )**

        Swaps this network proxy instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def capabilities(self) -> "QNetworkProxy.Capability":
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#capabilities

        **QNetworkProxy::Capabilities QNetworkProxy::capabilities() const**

        Returns the capabilities of this proxy server.

        **See also** **setCapabilities** () and **type** ().
        """
        ...

    def setCapabilities(self, capab: "QNetworkProxy.Capability") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setCapabilities

        **void QNetworkProxy::setCapabilities(QNetworkProxy::Capabilities
        capabilities )**

        Sets the capabilities of this proxy to **capabilities**.

        **See also** **setType** () and **capabilities** ().
        """
        ...

    def isTransparentProxy(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#isTransparentProxy

        **bool QNetworkProxy::isTransparentProxy() const**

        Returns `true` if this proxy supports transparent tunneling of TCP
        connections. This matches the **QNetworkProxy::TunnelingCapability**
        capability.

        In Qt 4.4, the capability was tied to the proxy type, but since Qt 4.5
        it is possible to remove the capability of caching from a proxy by
        calling **setCapabilities** ().

        **See also** **capabilities** (), **type** (), and **isCachingProxy**
        ().
        """
        ...

    def isCachingProxy(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#isCachingProxy

        **bool QNetworkProxy::isCachingProxy() const**

        Returns `true` if this proxy supports the
        **QNetworkProxy::CachingCapability**  capability.

        In Qt 4.4, the capability was tied to the proxy type, but since Qt 4.5
        it is possible to remove the capability of caching from a proxy by
        calling **setCapabilities** ().

        **See also** **capabilities** (), **type** (), and
        **isTransparentProxy** ().
        """
        ...

    @staticmethod
    def applicationProxy() -> "QNetworkProxy":
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#applicationProxy

        **[static] QNetworkProxy QNetworkProxy::applicationProxy()**

        Returns the application level network proxying.

        If a **QAbstractSocket**  or **QTcpSocket**  has the
        **QNetworkProxy::DefaultProxy**  type, then the **QNetworkProxy**
        returned by this function is used.

        **See also** **QNetworkProxyFactory** , **setApplicationProxy** (),
        **QAbstractSocket::proxy** (), and **QTcpServer::proxy** ().
        """
        ...

    @staticmethod
    def setApplicationProxy(proxy: "QNetworkProxy") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setApplicationProxy

        **[static] void QNetworkProxy::setApplicationProxy(const QNetworkProxy &
        networkProxy )**

        Sets the application level network proxying to be **networkProxy**.

        If a **QAbstractSocket**  or **QTcpSocket**  has the
        **QNetworkProxy::DefaultProxy**  type, then the **QNetworkProxy**  set
        with this function is used. If you want more flexibility in determining
        which proxy is used, use the **QNetworkProxyFactory**  class.

        Setting a default proxy value with this function will override the
        application proxy factory set with
        **QNetworkProxyFactory::setApplicationProxyFactory** , and disable the
        use of a system proxy.

        **See also** **QNetworkProxyFactory** , **applicationProxy** (),
        **QAbstractSocket::setProxy** (), and **QTcpServer::setProxy** ().
        """
        ...

    def port(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#port

        **quint16 QNetworkProxy::port() const**

        Returns the port of the proxy host.

        **See also** **setHostName** (), **setPort** (), and **hostName** ().
        """
        ...

    def setPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setPort

        **void QNetworkProxy::setPort(quint16 port )**

        Sets the port of the proxy host to be **port**.

        **See also** **hostName** (), **setHostName** (), and **port** ().
        """
        ...

    def hostName(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#hostName

        **QString QNetworkProxy::hostName() const**

        Returns the host name of the proxy host.

        **See also** **setHostName** (), **setPort** (), and **port** ().
        """
        ...

    def setHostName(self, hostName: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setHostName

        **void QNetworkProxy::setHostName(const QString & hostName )**

        Sets the host name of the proxy host to be **hostName**.

        **See also** **hostName** (), **setPort** (), and **port** ().
        """
        ...

    def password(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#password

        **QString QNetworkProxy::password() const**

        Returns the password used for authentication.

        **See also** **user** (), **setPassword** (), and **setUser** ().
        """
        ...

    def setPassword(self, password: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setPassword

        **void QNetworkProxy::setPassword(const QString & password )**

        Sets the password for proxy authentication to be **password**.

        **See also** **user** (), **setUser** (), and **password** ().
        """
        ...

    def user(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#user

        **QString QNetworkProxy::user() const**

        Returns the user name used for authentication.

        **See also** **setUser** (), **setPassword** (), and **password** ().
        """
        ...

    def setUser(self, userName: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setUser

        **void QNetworkProxy::setUser(const QString & user )**

        Sets the user name for proxy authentication to be **user**.

        **See also** **user** (), **setPassword** (), and **password** ().
        """
        ...

    def type(self) -> "QNetworkProxy.ProxyType":
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#type

        **QNetworkProxy::ProxyType QNetworkProxy::type() const**

        Returns the proxy type for this instance.

        **See also** **setType** ().
        """
        ...

    def setType(self, type: "QNetworkProxy.ProxyType") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxy.html#setType

        **void QNetworkProxy::setType(QNetworkProxy::ProxyType type )**

        Sets the proxy type for this instance to be **type**.

        Note that changing the type of a proxy does not change the set of
        capabilities this **QNetworkProxy**  object holds if any capabilities
        have been set with **setCapabilities** ().

        **See also** **type** () and **setCapabilities** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QMetaType(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetatype.html

    **Detailed Description**

    The class is used as a helper to marshall types in **QVariant**  and in
    queued signals and slots connections. It associates a type name to a type so
    that it can be created and destructed dynamically at run-time. Declare new
    types with **Q_DECLARE_METATYPE** () to make them available to **QVariant**
    and other template-based functions. Call **qRegisterMetaType** () to make
    types available to non-template based functions, such as the queued signal
    and slot connections.

    Any class or struct that has a public default constructor, a public copy
    constructor, and a public destructor can be registered.

    The following code allocates and destructs an instance of `MyClass`:

    int id = **QMetaType** ::type("MyClass");
        if (id != **QMetaType**
    ::UnknownType) {
            void *myClassPtr = **QMetaType** ::create(id);
    ...
            **QMetaType** ::destroy(id, myClassPtr);
            myClassPtr = 0;
    }

    If we want the stream operators `operator<<()` and `operator>>()` to work on
    **QVariant**  objects that store custom types, the custom type must provide
    `operator<<()` and `operator>>()` operators.

    **See also** **Q_DECLARE_METATYPE** (), **QVariant::setValue** (),
    **QVariant::value** (), and **QVariant::fromValue** ().
    """

    class TypeFlag(enum.Flag):
        NeedsConstruction: QMetaType = ...
        NeedsDestruction: QMetaType = ...
        PointerToQObject: QMetaType = ...
        IsEnumeration: QMetaType = ...
        IsUnsignedEnumeration: QMetaType = ...
        IsPointer: QMetaType = ...
        RelocatableType: QMetaType = ...
        IsQmlList: QMetaType = ...
        IsConst: QMetaType = ...

    class Type(enum.Enum):
        UnknownType: QMetaType = ...
        Void: QMetaType = ...
        Bool: QMetaType = ...
        Int: QMetaType = ...
        UInt: QMetaType = ...
        LongLong: QMetaType = ...
        ULongLong: QMetaType = ...
        Double: QMetaType = ...
        QChar: QMetaType = ...
        QVariantMap: QMetaType = ...
        QVariantList: QMetaType = ...
        QVariantHash: QMetaType = ...
        QString: QMetaType = ...
        QStringList: QMetaType = ...
        QByteArray: QMetaType = ...
        QBitArray: QMetaType = ...
        QDate: QMetaType = ...
        QTime: QMetaType = ...
        QDateTime: QMetaType = ...
        QUrl: QMetaType = ...
        QLocale: QMetaType = ...
        QRect: QMetaType = ...
        QRectF: QMetaType = ...
        QSize: QMetaType = ...
        QSizeF: QMetaType = ...
        QLine: QMetaType = ...
        QLineF: QMetaType = ...
        QPoint: QMetaType = ...
        QPointF: QMetaType = ...
        LastCoreType: QMetaType = ...
        FirstGuiType: QMetaType = ...
        QFont: QMetaType = ...
        QPixmap: QMetaType = ...
        QBrush: QMetaType = ...
        QColor: QMetaType = ...
        QPalette: QMetaType = ...
        QIcon: QMetaType = ...
        QImage: QMetaType = ...
        QPolygon: QMetaType = ...
        QRegion: QMetaType = ...
        QBitmap: QMetaType = ...
        QCursor: QMetaType = ...
        QSizePolicy: QMetaType = ...
        QKeySequence: QMetaType = ...
        QPen: QMetaType = ...
        QTextLength: QMetaType = ...
        QTextFormat: QMetaType = ...
        QTransform: QMetaType = ...
        VoidStar: QMetaType = ...
        Long: QMetaType = ...
        Short: QMetaType = ...
        Char: QMetaType = ...
        Char16: QMetaType = ...
        Char32: QMetaType = ...
        ULong: QMetaType = ...
        UShort: QMetaType = ...
        UChar: QMetaType = ...
        Float: QMetaType = ...
        QObjectStar: QMetaType = ...
        QMatrix4x4: QMetaType = ...
        QVector2D: QMetaType = ...
        QVector3D: QMetaType = ...
        QVector4D: QMetaType = ...
        QQuaternion: QMetaType = ...
        QEasingCurve: QMetaType = ...
        QVariant: QMetaType = ...
        QUuid: QMetaType = ...
        QModelIndex: QMetaType = ...
        QPolygonF: QMetaType = ...
        SChar: QMetaType = ...
        QRegularExpression: QMetaType = ...
        QJsonValue: QMetaType = ...
        QJsonObject: QMetaType = ...
        QJsonArray: QMetaType = ...
        QJsonDocument: QMetaType = ...
        QByteArrayList: QMetaType = ...
        QPersistentModelIndex: QMetaType = ...
        QCborSimpleType: QMetaType = ...
        QCborValue: QMetaType = ...
        QCborArray: QMetaType = ...
        QCborMap: QMetaType = ...
        QColorSpace: QMetaType = ...
        QVariantPair: QMetaType = ...
        User: QMetaType = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmetatype.html#QMetaType

        **[since 5.0] QMetaType::QMetaType(int typeId )**

        Constructs a QMetaType object that contains all information about type
        **typeId**.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def __init__(self, type: int) -> None:
        """
        https://doc.qt.io/qt-6/qmetatype.html#QMetaType

        **[since 5.0] QMetaType::QMetaType(int typeId )**

        Constructs a QMetaType object that contains all information about type
        **typeId**.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def canView(fromType: "QMetaType", toType: "QMetaType") -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#canView

        **[static] bool QMetaType::canView(QMetaType fromType , QMetaType toType
        )**

        Returns `true` if **QMetaType::view**  can create a mutable view of type
        **toType** on type **fromType**.

        Converting between pointers of types derived from **QObject**  will
        return true for this function if a **qobject_cast**  from the type
        described by **fromType** to the type described by **toType** would
        succeed.

        You can create a mutable view of type **QSequentialIterable**  on any
        container registered with **Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE**
        ().

        Similarly you can create a mutable view of type **QAssociativeIterable**
        on any container registered with
        **Q_DECLARE_ASSOCIATIVE_CONTAINER_METATYPE** ().

        **See also** **convert** (), **QSequentialIterable** ,
        **Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE** (), **QAssociativeIterable**
        , and **Q_DECLARE_ASSOCIATIVE_CONTAINER_METATYPE** ().
        """
        ...

    @staticmethod
    def canConvert(fromType: "QMetaType", toType: "QMetaType") -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#canConvert

        **[static] bool QMetaType::canConvert(QMetaType fromType , QMetaType
        toType )**

        Returns `true` if **QMetaType::convert**  can convert from **fromType**
        to **toType**.

        The following conversions are supported by Qt:

        TypeAutomatically Cast To
        **QMetaType::Bool** **QMetaType::QChar** ,
        **QMetaType::Double** , **QMetaType::Int** , **QMetaType::LongLong** ,
        **QMetaType::QString** , **QMetaType::UInt** , **QMetaType::ULongLong**
        **QMetaType::QByteArray** **QMetaType::Double** , **QMetaType::Int** ,
        **QMetaType::LongLong** , **QMetaType::QString** , **QMetaType::UInt** ,
        **QMetaType::ULongLong** , **QMetaType::QUuid**
        **QMetaType::QChar**
        **QMetaType::Bool** , **QMetaType::Int** , **QMetaType::UInt** ,
        **QMetaType::LongLong** , **QMetaType::ULongLong**
        **QMetaType::QColor** **QMetaType::QString**
        **QMetaType::QDate**
        **QMetaType::QDateTime** , **QMetaType::QString**
        **QMetaType::QDateTime** **QMetaType::QDate** , **QMetaType::QString** ,
        **QMetaType::QTime**
        **QMetaType::Double** **QMetaType::Bool** ,
        **QMetaType::Int** , **QMetaType::LongLong** , **QMetaType::QString** ,
        **QMetaType::UInt** , **QMetaType::ULongLong**
        **QMetaType::QFont**
        **QMetaType::QString**
        **QMetaType::Int** **QMetaType::Bool** ,
        **QMetaType::QChar** , **QMetaType::Double** , **QMetaType::LongLong** ,
        **QMetaType::QString** , **QMetaType::UInt** , **QMetaType::ULongLong**
        **QMetaType::QKeySequence** **QMetaType::Int** , **QMetaType::QString**
        **QMetaType::QVariantList** **QMetaType::QStringList**  (if the list's
        items can be converted to QStrings)
        **QMetaType::LongLong**
        **QMetaType::Bool** , **QMetaType::QByteArray** , **QMetaType::QChar** ,
        **QMetaType::Double** , **QMetaType::Int** , **QMetaType::QString** ,
        **QMetaType::UInt** , **QMetaType::ULongLong**
        **QMetaType::QPoint**
        **QMetaType::QPointF**
        **QMetaType::QRect** **QMetaType::QRectF**
        **QMetaType::QString** **QMetaType::Bool** , **QMetaType::QByteArray** ,
        **QMetaType::QChar** , **QMetaType::QColor** , **QMetaType::QDate** ,
        **QMetaType::QDateTime** , **QMetaType::Double** , **QMetaType::QFont**
        , **QMetaType::Int** , **QMetaType::QKeySequence** ,
        **QMetaType::LongLong** , **QMetaType::QStringList** ,
        **QMetaType::QTime** , **QMetaType::UInt** , **QMetaType::ULongLong** ,
        **QMetaType::QUuid**
        **QMetaType::QStringList**
        **QMetaType::QVariantList** , **QMetaType::QString**  (if the list
        contains exactly one item)
        **QMetaType::QTime** **QMetaType::QString**
        **QMetaType::UInt** **QMetaType::Bool** , **QMetaType::QChar** ,
        **QMetaType::Double** , **QMetaType::Int** , **QMetaType::LongLong** ,
        **QMetaType::QString** , **QMetaType::ULongLong**
        **QMetaType::ULongLong** **QMetaType::Bool** , **QMetaType::QChar** ,
        **QMetaType::Double** , **QMetaType::Int** , **QMetaType::LongLong** ,
        **QMetaType::QString** , **QMetaType::UInt**
        **QMetaType::QUuid**
        **QMetaType::QByteArray** , **QMetaType::QString**

        Casting between primitive type (int, float, bool etc.) is supported.

        Converting between pointers of types derived from **QObject**  will also
        return true for this function if a **qobject_cast**  from the type
        described by **fromType** to the type described by **toType** would
        succeed.

        A cast from a sequential container will also return true for this
        function if the **toType** is **QVariantList** .

        Similarly, a cast from an associative container will also return true
        for this function the **toType** is **QVariantHash**  or **QVariantMap**
        .

        **See also** **convert** (), **QSequentialIterable** ,
        **Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE** (), **QAssociativeIterable**
        , and **Q_DECLARE_ASSOCIATIVE_CONTAINER_METATYPE** ().
        """
        ...

    @staticmethod
    def fromName(
        name: typing.Union[QByteArray, bytes, bytearray, memoryview]
    ) -> "QMetaType":
        """
        https://doc.qt.io/qt-6/qmetatype.html#fromName

        **[static] QMetaType QMetaType::fromName(QByteArrayView typeName )**

        Returns a **QMetaType**  matching **typeName**. The returned object is
        not valid if the typeName is not known to **QMetaType**
        """
        ...

    def isOrdered(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#isOrdered

        **bool QMetaType::isOrdered() const**

        Returns `true` if a less than operator for the type described by this
        metatype was visible to the metatype declaration, otherwise `false`.

        **See also** **compare** () and **isEqualityComparable** ().
        """
        ...

    def isEqualityComparable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#isEqualityComparable

        **bool QMetaType::isEqualityComparable() const**

        Returns `true` if a less than or equality operator for the type
        described by this metatype was visible to the metatype declaration,
        otherwise `false`.

        **See also** **equals** () and **isOrdered** ().
        """
        ...

    def alignOf(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetatype.html#alignOf

        **[since 6.0] qsizetype QMetaType::alignOf() const**

        Returns the alignment of the type in bytes (i.e. alignof(T), where T is
        the actual type for which this **QMetaType**  instance was constructed
        for).

        This function is typically used together with construct() to perform
        low-level management of the memory used by a type.

        This function was introduced in Qt 6.0.

        **See also** **QMetaType::construct** () and **QMetaType::sizeOf** ().
        """
        ...

    def name(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qmetatype.html#name

        **[since 5.15] const char *QMetaType::name() const**

        Returns the type name associated with this **QMetaType** , or a null
        pointer if no matching type was found. The returned pointer must not be
        deleted.

        This function was introduced in Qt 5.15.

        **See also** **typeName** ().
        """
        ...

    def hasRegisteredDebugStreamOperator(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#hasRegisteredDebugStreamOperator

        **[since 6.0] bool QMetaType::hasRegisteredDebugStreamOperator() const**

        Returns `true`, if the meta type system has a registered debug stream
        operator for this meta type.

        This function was introduced in Qt 6.0.
        """
        ...

    def hasRegisteredDataStreamOperators(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#hasRegisteredDataStreamOperators

        **[since 6.1] bool QMetaType::hasRegisteredDataStreamOperators() const**

        Returns `true`, if the meta type system has registered data stream
        operators for this meta type.

        This function was introduced in Qt 6.1.
        """
        ...

    def id(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetatype.html#id

        **[since 5.13] int QMetaType::id() const**

        Returns id type hold by this QMetatype instance.

        This function was introduced in Qt 5.13.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#isValid

        **[since 5.0] bool QMetaType::isValid() const**

        Returns `true` if this **QMetaType**  object contains valid information
        about a type, false otherwise.

        This function was introduced in Qt 5.0.
        """
        ...

    def flags(self) -> "QMetaType.TypeFlag":
        """
        https://doc.qt.io/qt-6/qmetatype.html#flags

        **[since 5.0] QMetaType::TypeFlags QMetaType::flags() const**

        Returns flags of the type for which this **QMetaType**  instance was
        constructed.

        This function was introduced in Qt 5.0.

        **See also** **QMetaType::TypeFlags**  and QMetaType::flags().
        """
        ...

    def sizeOf(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetatype.html#sizeOf-1

        **[since 5.0] qsizetype QMetaType::sizeOf() const**

        Returns the size of the type in bytes (i.e. sizeof(T), where T is the
        actual type for which this **QMetaType**  instance was constructed for).

        This function is typically used together with construct() to perform
        low-level management of the memory used by a type.

        This function was introduced in Qt 5.0.

        **See also** **QMetaType::construct** (), QMetaType::sizeOf(), and
        **QMetaType::alignOf** ().
        """
        ...

    @typing.overload
    @staticmethod
    def isRegistered(type: int) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#isRegistered

        **[static] bool QMetaType::isRegistered(int type )**

        Returns `true` if the datatype with ID **type** is registered; otherwise
        returns `false`.

        **See also** **type** (), **typeName** (), and **Type** .
        """
        ...

    @typing.overload
    def isRegistered(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetatype.html#isRegistered-1

        **[since 5.0] bool QMetaType::isRegistered() const**

        Returns `true` if this **QMetaType**  object contains valid information
        about a type, false otherwise.

        This function was introduced in Qt 5.0.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QByteArray(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbytearray.html

    **Detailed Description**

    QByteArray can be used to store both raw bytes (including '\\0's) and
    traditional 8-bit '\\0'-terminated strings. Using QByteArray is much more
    convenient than using `const char *`. Behind the scenes, it always ensures
    that the data is followed by a '\\0' terminator, and uses **implicit
    sharing**  (copy-on-write) to reduce memory usage and avoid needless copying
    of data.

    In addition to QByteArray, Qt also provides the **QString**  class to store
    string data. For most purposes, **QString**  is the class you want to use.
    It understands its content as Unicode text (encoded using UTF-16) where
    QByteArray aims to avoid assumptions about the encoding or semantics of the
    bytes it stores (aside from a few legacy cases where it uses ASCII).
    Furthermore, **QString**  is used throughout in the Qt API. The two main
    cases where QByteArray is appropriate are when you need to store raw binary
    data, and when memory conservation is critical (e.g., with Qt for Embedded
    Linux).

    One way to initialize a QByteArray is simply to pass a `const char *` to its
    constructor. For example, the following code creates a byte array of size 5
    containing the data "Hello":

    **QByteArray**  ba("Hello");

    Although the **size** () is 5, the byte array also maintains an extra '\\0'
    byte at the end so that if a function is used that asks for a pointer to the
    underlying data (e.g. a call to **data** ()), the data pointed to is
    guaranteed to be '\\0'-terminated.

    QByteArray makes a deep copy of the `const char *` data, so you can modify
    it later without experiencing side effects. (If, for example for performance
    reasons, you don't want to take a deep copy of the data, use
    **QByteArray::fromRawData** () instead.)

    Another approach is to set the size of the array using **resize** () and to
    initialize the data byte by byte. QByteArray uses 0-based indexes, just like
    C++ arrays. To access the byte at a particular index position, you can use
    operator[](). On non-const byte arrays, operator[]() returns a reference to
    a byte that can be used on the left side of an assignment. For example:

    **QByteArray**  ba;
        ba.resize(5);
        ba[0] = 0x3c;
        ba[1] = 0xb8;
    ba[2] = 0x64;
        ba[3] = 0x18;
        ba[4] = 0xca;

    For read-only access, an alternative syntax is to use **at** ():

    for (qsizetype i = 0; i < ba.size(); ++i) {
            if (ba.at(i) >= 'a' &&
    ba.at(i) <= 'f')
                cout << "Found character in range [a-f]" <<
    Qt::endl;
        }

    **at** () can be faster than operator[](), because it never causes a **deep
    copy**  to occur.

    To extract many bytes at a time, use **first** (), **last** (), or
    **sliced** ().

    A QByteArray can embed '\\0' bytes. The **size** () function always returns
    the size of the whole array, including embedded '\\0' bytes, but excluding
    the terminating '\\0' added by QByteArray. For example:

    **QByteArray**  ba1("ca\\0r\\0t");
        ba1.size();                     //
    Returns 2.
        ba1.constData();                // Returns "ca" with
    terminating \\0.

        **QByteArray**  ba2("ca\\0r\\0t", 3);
        ba2.size();
    // Returns 3.
        ba2.constData();                // Returns "ca\\0" with
    terminating \\0.

        **QByteArray**  ba3("ca\\0r\\0t", 4);
        ba3.size();
    // Returns 4.
        ba3.constData();                // Returns "ca\\0r" with
    terminating \\0.

        const char cart[] = {'c', 'a', '\\0', 'r', '\\0',
    't'};
        **QByteArray**  ba4(**QByteArray** ::fromRawData(cart, 6));
    ba4.size();                     // Returns 6.
        ba4.constData();
    // Returns "ca\\0r\\0t" without terminating \\0.

    If you want to obtain the length of the data up to and excluding the first
    '\\0' byte, call **qstrlen** () on the byte array.

    After a call to **resize** (), newly allocated bytes have undefined values.
    To set all the bytes to a particular value, call **fill** ().

    To obtain a pointer to the actual bytes, call **data** () or **constData**
    (). These functions return a pointer to the beginning of the data. The
    pointer is guaranteed to remain valid until a non-const function is called
    on the QByteArray. It is also guaranteed that the data ends with a '\\0' byte
    unless the QByteArray was created from **raw data** . This '\\0' byte is
    automatically provided by QByteArray and is not counted in **size** ().

    QByteArray provides the following basic functions for modifying the byte
    data: **append** (), **prepend** (), **insert** (), **replace** (), and
    **remove** (). For example:

    **QByteArray**  x("and");
        x.prepend("rock ");         // x == "rock and"
    x.append(" roll");          // x == "rock and roll"
        x.replace(5, 3,
    "&");       // x == "rock & roll"

    In the above example the **replace** () function's first two arguments are
    the position from which to start replacing and the number of bytes that
    should be replaced.

    When data-modifying functions increase the size of the array, they may lead
    to reallocation of memory for the QByteArray object. When this happens,
    QByteArray expands by more than it immediately needs so as to have space for
    further expansion without reallocation until the size of the array has
    greatly increased.

    The **insert** (), **remove** () and, when replacing a sub-array with one of
    different size, **replace** () functions can be slow (**linear time** ) for
    large arrays, because they require moving many bytes in the array by at
    least one position in memory.

    If you are building a QByteArray gradually and know in advance approximately
    how many bytes the QByteArray will contain, you can call **reserve** (),
    asking QByteArray to preallocate a certain amount of memory. You can also
    call **capacity** () to find out how much memory the QByteArray actually has
    allocated.

    Note that using non-const operators and functions can cause QByteArray to do
    a deep copy of the data, due to **implicit sharing** .

    QByteArray provides **STL-style iterators**  (**QByteArray::const_iterator**
    and **QByteArray::iterator** ). In practice, iterators are handy when
    working with generic algorithms provided by the C++ standard library.

    **Note:** Iterators and references to individual QByteArray elements are
    subject to stability issues. They are often invalidated when a QByteArray-
    modifying operation (e.g. **insert** () or **remove** ()) is called. When
    stability and iterator-like functionality is required, you should use
    indexes instead of iterators as they are not tied to QByteArray's internal
    state and thus do not get invalidated.

    **Note:** Iterators over a QByteArray, and references to individual bytes
    within one, cannot be relied on to remain valid when any non-const method of
    the QByteArray is called. Accessing such an iterator or reference after the
    call to a non-const method leads to undefined behavior. When stability for
    iterator-like functionality is required, you should use indexes instead of
    iterators as they are not tied to QByteArray's internal state and thus do
    not get invalidated.

    If you want to find all occurrences of a particular byte or sequence of
    bytes in a QByteArray, use **indexOf** () or **lastIndexOf** (). The former
    searches forward starting from a given index position, the latter searches
    backward. Both return the index position of the byte sequence if they find
    it; otherwise, they return -1. For example, here's a typical loop that finds
    all occurrences of a particular string:

    **QByteArray**  ba("We must be <b>bold</b>, very <b>bold</b>");
    qsizetype j = 0;
        while ((j = ba.indexOf("<b>", j)) != -1) {
            cout
    << "Found <b> tag at index position " << j << Qt::endl;
            ++j;
        }

    If you simply want to check whether a QByteArray contains a particular byte
    sequence, use **contains** (). If you want to find out how many times a
    particular byte sequence occurs in the byte array, use **count** (). If you
    want to replace all occurrences of a particular value with another, use one
    of the two-parameter **replace** () overloads.

    **QByteArray** s can be compared using overloaded operators such as
    operator<(), operator<=(), operator==(), operator>=(), and so on. The
    comparison is based exclusively on the numeric values of the bytes and is
    very fast, but is not what a human would expect.
    **QString::localeAwareCompare** () is a better choice for sorting user-
    interface strings.

    For historical reasons, QByteArray distinguishes between a null byte array
    and an empty byte array. A **null** byte array is a byte array that is
    initialized using QByteArray's default constructor or by passing (const char
    *)0 to the constructor. An **empty** byte array is any byte array with size
    0. A null byte array is always empty, but an empty byte array isn't
    necessarily null:

    **QByteArray** ().isNull();          // returns true
        **QByteArray**
    ().isEmpty();         // returns true

        **QByteArray** ("").isNull();
    // returns false
        **QByteArray** ("").isEmpty();       // returns true
    **QByteArray** ("abc").isNull();     // returns false
        **QByteArray**
    ("abc").isEmpty();    // returns false

    All functions except **isNull** () treat null byte arrays the same as empty
    byte arrays. For example, **data** () returns a valid pointer ( **not**
    nullptr) to a '\\0' byte for a null byte array and QByteArray() compares
    equal to QByteArray(""). We recommend that you always use **isEmpty** () and
    avoid **isNull** ().

    **Maximum size and out-of-memory conditions**

    The maximum size of QByteArray depends on the architecture. Most 64-bit
    systems can allocate more than 2 GB of memory, with a typical limit of 2^63
    bytes. The actual value also depends on the overhead required for managing
    the data block. As a result, you can expect the maximum size of 2 GB minus
    overhead on 32-bit platforms, and 2^63 bytes minus overhead on 64-bit
    platforms. The number of elements that can be stored in a QByteArray is this
    maximum size.

    When memory allocation fails, QByteArray throws a `std::bad_alloc` exception
    if the application is being compiled with exception support. Out of memory
    conditions in Qt containers are the only case where Qt will throw
    exceptions. If exceptions are disabled, then running out of memory is
    undefined behavior.

    Note that the operating system may impose further limits on applications
    holding a lot of allocated memory, especially large, contiguous blocks. Such
    considerations, the configuration of such behavior or any mitigation are
    outside the scope of the QByteArray API.

    **C locale and ASCII functions**

    QByteArray generally handles data as bytes, without presuming any semantics;
    where it does presume semantics, it uses the C locale and ASCII encoding.
    Standard Unicode encodings are supported by **QString** , other encodings
    may be supported using **QStringEncoder**  and **QStringDecoder**  to
    convert to Unicode. For locale-specific interpretation of text, use
    **QLocale**  or **QString** .

    **C Strings**

    Traditional C strings, also known as '\\0'-terminated strings, are sequences
    of bytes, specified by a start-point and implicitly including each byte up
    to, but not including, the first '\\0' byte thereafter. Methods that accept
    such a pointer, without a length, will interpret it as this sequence of
    bytes. Such a sequence, by construction, cannot contain a '\\0' byte.

    Other overloads accept a start-pointer and a byte-count; these use the given
    number of bytes, following the start address, regardless of whether any of
    them happen to be '\\0' bytes. In some cases, where there is no overload
    taking only a pointer, passing a length of -1 will cause the method to use
    the offset of the first '\\0' byte after the pointer as the length; a length
    of -1 should only be passed if the method explicitly says it does this (in
    which case it is typically a default argument).

    **Spacing Characters**

    A frequent requirement is to remove spacing characters from a byte array
    (`'\\n'`, `'\\t'`, `' '`, etc.). If you want to remove spacing from both ends
    of a QByteArray, use **trimmed** (). If you want to also replace each run of
    spacing characters with a single space character within the byte array, use
    **simplified** (). Only ASCII spacing characters are recognized for these
    purposes.

    **Number-String Conversions**

    Functions that perform conversions between numeric data types and string
    representations are performed in the C locale, regardless of the user's
    locale settings. Use **QLocale**  to perform locale-aware conversions
    between numbers and strings.

    **Character Case**

    In QByteArray, the notion of uppercase and lowercase and of case-independent
    comparison is limited to ASCII. Non-ASCII characters are treated as
    caseless, since their case depends on encoding. This affects functions that
    support a case insensitive option or that change the case of their
    arguments. Functions that this affects include **contains** (), **indexOf**
    (), **lastIndexOf** (), **isLower** (), **isUpper** (), **toLower** () and
    **toUpper** ().

    This issue does not apply to **QString** s since they represent characters
    using Unicode.

    **See also** **QByteArrayView** , **QString** , and **QBitArray** .
    """

    class Base64DecodingStatus(enum.Enum):
        Ok: QByteArray = ...
        IllegalInputLength: QByteArray = ...
        IllegalCharacter: QByteArray = ...
        IllegalPadding: QByteArray = ...

    class Base64Option(enum.Flag):
        Base64Encoding: QByteArray = ...
        Base64UrlEncoding: QByteArray = ...
        KeepTrailingEquals: QByteArray = ...
        OmitTrailingEquals: QByteArray = ...
        IgnoreBase64DecodingErrors: QByteArray = ...
        AbortOnBase64DecodingErrors: QByteArray = ...

    class FromBase64Result(PyQt6.sip.simplewrapper):
        decoded = ...
        decodingStatus = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QByteArray.FromBase64Result") -> None:
            ...

        def __hash__(self) -> int:
            ...

        def __int__(self) -> bool:
            ...

        def swap(self, other: "QByteArray.FromBase64Result") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#QByteArray

        **QByteArray::QByteArray()**

        Constructs an empty byte array.

        **See also** **isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(self, size: int, c: bytes) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#QByteArray-1

        **QByteArray::QByteArray(const char * data , qsizetype size = -1)**

        Constructs a byte array containing the first **size** bytes of array
        **data**.

        If **data** is 0, a null byte array is constructed.

        If **size** is negative, **data** is assumed to point to a
        '\\0'-terminated string and its length is determined dynamically.

        QByteArray makes a deep copy of the string data.

        **See also** **fromRawData** ().
        """
        ...

    @typing.overload
    def __init__(self, a: "QByteArray") -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#QByteArray-2

        **QByteArray::QByteArray(qsizetype size , char ch )**

        Constructs a byte array of size **size** with every byte set to **ch**.

        **See also** **fill** ().
        """
        ...

    @typing.overload
    def sliced(self, pos: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#sliced

        **[since 6.0] QByteArray QByteArray::sliced(qsizetype pos , qsizetype n
        ) const**

        Returns a byte array containing the **n** bytes of this object starting
        at position **pos**.

        **Note:** The behavior is undefined when **pos** < 0, **n** < 0, or
        **pos** \\+ **n** > **size** ().

        Example:

        **QByteArray**  x("Five pineapples");
            **QByteArray**  y =
        x.sliced(5, 4);     // y == "pine"
            **QByteArray**  z = x.sliced(5);
        // z == "pineapples"

        This function was introduced in Qt 6.0.

        **See also** **first** (), **last** (), **chopped** (), **chop** (), and
        **truncate** ().
        """
        ...

    @typing.overload
    def sliced(self, pos: int, n: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#sliced-1

        **[since 6.0] QByteArray QByteArray::sliced(qsizetype pos ) const**

        This is an overloaded function.

        Returns a byte array containing the bytes starting at position **pos**
        in this object, and extending to the end of this object.

        **Note:** The behavior is undefined when **pos** < 0 or **pos** >
        **size** ().

        This function was introduced in Qt 6.0.

        **See also** **first** (), **last** (), **sliced** (), **chopped** (),
        **chop** (), and **truncate** ().
        """
        ...

    @staticmethod
    def fromBase64Encoding(
        base64: "QByteArray", options: "QByteArray.Base64Option" = ...
    ) -> "QByteArray.FromBase64Result":
        ...

    def isLower(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#isLower

        **[since 5.12] bool QByteArray::isLower() const**

        Returns `true` if this byte array contains only lowercase ASCII letters,
        otherwise returns `false`.

        This function was introduced in Qt 5.12.

        **See also** **isUpper** () and **toLower** ().
        """
        ...

    def isUpper(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#isUpper

        **[since 5.12] bool QByteArray::isUpper() const**

        Returns `true` if this byte array contains only ASCII uppercase letters,
        otherwise returns `false`.

        This function was introduced in Qt 5.12.

        **See also** **isLower** () and **toUpper** ().
        """
        ...

    def compare(
        self,
        a: typing.Union["QByteArray", bytes, bytearray, memoryview],
        cs: Qt.CaseSensitivity = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#compare

        **[since 6.0] int QByteArray::compare(QByteArrayView bv ,
        Qt::CaseSensitivity cs = Qt::CaseSensitive) const**

        Returns an integer less than, equal to, or greater than zero depending
        on whether this **QByteArray**  sorts before, at the same position as,
        or after the **QByteArrayView**  **bv**. The comparison is performed
        according to case sensitivity **cs**.

        This function was introduced in Qt 6.0.

        **See also** **operator==**  and **Character Case** .
        """
        ...

    def chopped(self, len: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#chopped

        **[since 5.10] QByteArray QByteArray::chopped(qsizetype len ) const**

        Returns a byte array that contains the leftmost **size** () - **len**
        bytes of this byte array.

        **Note:** The behavior is undefined if **len** is negative or greater
        than **size** ().

        This function was introduced in Qt 5.10.

        **See also** **endsWith** (), **first** (), **last** (), **sliced** (),
        **chop** (), and **truncate** ().
        """
        ...

    def swap(self, other: "QByteArray") -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#swap

        **void QByteArray::swap(QByteArray & other )**

        Swaps byte array **other** with this byte array. This operation is very
        fast and never fails.
        """
        ...

    def repeated(self, times: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#repeated

        **QByteArray QByteArray::repeated(qsizetype times ) const**

        Returns a copy of this byte array repeated the specified number of
        **times**.

        If **times** is less than 1, an empty byte array is returned.

        Example:

        **QByteArray**  ba("ab");
            ba.repeated(4);             // returns
        "abababab"
        """
        ...

    @staticmethod
    def fromPercentEncoding(input: "QByteArray", percent: str = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#fromPercentEncoding

        **[static] QByteArray QByteArray::fromPercentEncoding(const QByteArray &
        input , char percent = '%')**

        Returns a decoded copy of the URI/URL-style percent-encoded **input**.
        The **percent** parameter allows you to replace the '%' character for
        another (for instance, '_' or '=').

        For example:

        **QByteArray**  text = **QByteArray**
        ::fromPercentEncoding("Qt%20is%20great%33");
            text.data();
        // returns "Qt is great!"

        **Note:** Given invalid input (such as a string containing the sequence
        "%G5", which is not a valid hexadecimal number) the output will be
        invalid as well. As an example: the sequence "%G5" could be decoded to
        'W'.

        **See also** **toPercentEncoding** () and **QUrl::fromPercentEncoding**
        ().
        """
        ...

    def toPercentEncoding(
        self,
        exclude: "QByteArray" = ...,
        include: "QByteArray" = ...,
        percent: str = ...,
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#toPercentEncoding

        **QByteArray QByteArray::toPercentEncoding(const QByteArray & exclude =
        QByteArray(), const QByteArray & include = QByteArray(), char percent =
        '%') const**

        Returns a URI/URL-style percent-encoded copy of this byte array. The
        **percent** parameter allows you to override the default '%' character
        for another.

        By default, this function will encode all bytes that are not one of the
        following:

        ALPHA ("a" to "z" and "A" to "Z") / DIGIT (0 to 9) / "-" / "." / "_" /
        "~"

        To prevent bytes from being encoded pass them to **exclude**. To force
        bytes to be encoded pass them to **include**. The **percent** character
        is always encoded.

        Example:

        **QByteArray**  text = "{a fishy string?}";
            **QByteArray**  ba =
        text.toPercentEncoding("{}", "s");
            **qDebug** (ba.constData());
        // prints "{a fi%73hy %73tring%3F}"

        The hex encoding uses the numbers 0-9 and the uppercase letters A-F.

        **See also** **fromPercentEncoding** () and **QUrl::toPercentEncoding**
        ().
        """
        ...

    def toHex(self, separator: bytes = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#toHex

        **[since 5.9] QByteArray QByteArray::toHex(char separator = '\\0')
        const**

        Returns a hex encoded copy of the byte array.

        The hex encoding uses the numbers 0-9 and the letters a-f.

        If **separator** is not '\\0', the separator character is inserted
        between the hex bytes.

        Example:

        **QByteArray**  macAddress = **QByteArray** ::fromHex("123456abcdef");
        macAddress.toHex(':'); // returns "12:34:56:ab:cd:ef"
        macAddress.toHex(0);   // returns "123456abcdef"

        This function was introduced in Qt 5.9.

        **See also** **fromHex** ().
        """
        ...

    def contains(
        self, bv: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#contains

        **[since 6.0] bool QByteArray::contains(QByteArrayView bv ) const**

        Returns `true` if this byte array contains an occurrence of the sequence
        of bytes viewed by **bv** ; otherwise returns `false`.

        This function was introduced in Qt 6.0.

        **See also** **indexOf** () and **count** ().
        """
        ...

    def push_front(
        self, a: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#push_front

        **void QByteArray::push_front(const QByteArray & other )**

        This function is provided for STL compatibility. It is equivalent to
        prepend( **other** ).
        """
        ...

    def push_back(
        self, a: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#push_back

        **void QByteArray::push_back(const QByteArray & other )**

        This function is provided for STL compatibility. It is equivalent to
        append( **other** ).
        """
        ...

    def squeeze(self) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#squeeze

        **void QByteArray::squeeze()**

        Releases any memory not required to store the array's data.

        The sole purpose of this function is to provide a means of fine tuning
        **QByteArray** 's memory usage. In general, you will rarely ever need to
        call this function.

        **See also** **reserve** () and **capacity** ().
        """
        ...

    def reserve(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#reserve

        **void QByteArray::reserve(qsizetype size )**

        Attempts to allocate memory for at least **size** bytes.

        If you know in advance how large the byte array will be, you can call
        this function, and if you call **resize** () often you are likely to get
        better performance.

        If in doubt about how much space shall be needed, it is usually better
        to use an upper bound as **size** , or a high estimate of the most
        likely size, if a strict upper bound would be much bigger than this. If
        **size** is an underestimate, the array will grow as needed once the
        reserved size is exceeded, which may lead to a larger allocation than
        your best overestimate would have and will slow the operation that
        triggers it.

        **Warning:** reserve() reserves memory but does not change the size of
        the byte array. Accessing data beyond the end of the byte array is
        undefined behavior. If you need to access memory beyond the current end
        of the array, use **resize** ().

        The sole purpose of this function is to provide a means of fine tuning
        **QByteArray** 's memory usage. In general, you will rarely ever need to
        call this function.

        **See also** **squeeze** () and **capacity** ().
        """
        ...

    def capacity(self) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#capacity

        **qsizetype QByteArray::capacity() const**

        Returns the maximum number of bytes that can be stored in the byte array
        without forcing a reallocation.

        The sole purpose of this function is to provide a means of fine tuning
        **QByteArray** 's memory usage. In general, you will rarely ever need to
        call this function. If you want to know how many bytes are in the byte
        array, call **size** ().

        **Note:** a statically allocated byte array will report a capacity of 0,
        even if it's not empty.

        **Note:** The free space position in the allocated memory block is
        undefined. In other words, one should not assume that the free memory is
        always located after the initialized elements.

        **See also** **reserve** () and **squeeze** ().
        """
        ...

    def data(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qbytearray.html#data

        **char *QByteArray::data()**

        Returns a pointer to the data stored in the byte array. The pointer can
        be used to access and modify the bytes that compose the array. The data
        is '\\0'-terminated, i.e. the number of bytes you can access following
        the returned pointer is **size** () + 1, including the '\\0' terminator.

        Example:

        **QByteArray**  ba("Hello world");
            char *data = ba.data();
            while
        (*data) {
                cout << "[" << *data << "]" << Qt::endl;
        ++data;
            }

        The pointer remains valid as long as no detach happens and the
        **QByteArray**  is not modified.

        For read-only access, **constData** () is faster because it never causes
        a **deep copy**  to occur.

        This function is mostly useful to pass a byte array to a function that
        accepts a `const char *`.

        The following example makes a copy of the char* returned by data(), but
        it will corrupt the heap and cause a crash because it does not allocate
        a byte for the '\\0' at the end:

        **QString**  tmp = "test";
            **QByteArray**  text = tmp.toLocal8Bit();
        char *data = new char[text.size()];
            strcpy(data, text.data());
        delete [] data;

        This one allocates the correct amount of space:

        **QString**  tmp = "test";
            **QByteArray**  text = tmp.toLocal8Bit();
        char *data = new char[text.size() + 1];
            strcpy(data, text.data());
        delete [] data;

        Note: A **QByteArray**  can store any byte values including '\\0's, but
        most functions that take `char *` arguments assume that the data ends at
        the first '\\0' they encounter.

        **See also** **constData** () and **operator[]** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#isEmpty

        **bool QByteArray::isEmpty() const**

        Returns `true` if the byte array has size 0; otherwise returns `false`.

        Example:

        **QByteArray** ().isEmpty();         // returns true
            **QByteArray**
        ("").isEmpty();       // returns true
            **QByteArray**
        ("abc").isEmpty();    // returns false

        **See also** **size** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    def __str__(self) -> str:
        ...

    def __hash__(self) -> int:
        ...

    def __contains__(
        self, bv: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> int:
        ...

    @typing.overload
    def __getitem__(self, i: int) -> bytes:
        ...

    @typing.overload
    def __getitem__(self, slice: slice) -> "QByteArray":
        ...

    def at(self, i: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qbytearray.html#at

        **char QByteArray::at(qsizetype i ) const**

        Returns the byte at index position **i** in the byte array.

        **i** must be a valid index position in the byte array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **operator[]** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#size

        **qsizetype QByteArray::size() const**

        Returns the number of bytes in this byte array.

        The last byte in the byte array is at position size() - 1. In addition,
        **QByteArray**  ensures that the byte at position size() is always '\\0',
        so that you can use the return value of **data** () and **constData** ()
        as arguments to functions that expect '\\0'-terminated strings. If the
        **QByteArray**  object was created from a **raw data**  that didn't
        include the trailing '\\0'-termination byte, then **QByteArray**  doesn't
        add it automatically unless a **deep copy**  is created.

        Example:

        **QByteArray**  ba("Hello");
            qsizetype n = ba.size();    // n == 5
        ba.data()[0];               // returns 'H'
            ba.data()[4];
        // returns 'o'
            ba.data()[5];               // returns '\\0'

        **See also** **isEmpty** () and **resize** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#isNull

        **bool QByteArray::isNull() const**

        Returns `true` if this byte array is null; otherwise returns `false`.

        Example:

        **QByteArray** ().isNull();          // returns true
            **QByteArray**
        ("").isNull();        // returns false
            **QByteArray**
        ("abc").isNull();     // returns false

        Qt makes a distinction between null byte arrays and empty byte arrays
        for historical reasons. For most applications, what matters is whether
        or not a byte array contains any data, and this can be determined using
        **isEmpty** ().

        **See also** **isEmpty** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#length

        **qsizetype QByteArray::length() const**

        Same as **size** ().
        """
        ...

    @staticmethod
    def fromHex(hexEncoded: "QByteArray") -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#fromHex

        **[static] QByteArray QByteArray::fromHex(const QByteArray & hexEncoded
        )**

        Returns a decoded copy of the hex encoded array **hexEncoded**. Input is
        not checked for validity; invalid characters in the input are skipped,
        enabling the decoding process to continue with subsequent characters.

        For example:

        **QByteArray**  text = **QByteArray**
        ::fromHex("517420697320677265617421");
            text.data();            //
        returns "Qt is great!"

        **See also** **toHex** ().
        """
        ...

    @staticmethod
    def fromBase64(
        base64: "QByteArray", options: "QByteArray.Base64Option" = ...
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#fromBase64

        **[static, since 5.2] QByteArray QByteArray::fromBase64(const QByteArray
        & base64 , QByteArray::Base64Options options = Base64Encoding)**

        Returns a decoded copy of the Base64 array **base64** , using the
        options defined by **options**. If **options** contains
        `IgnoreBase64DecodingErrors` (the default), the input is not checked for
        validity; invalid characters in the input are skipped, enabling the
        decoding process to continue with subsequent characters. If **options**
        contains `AbortOnBase64DecodingErrors`, then decoding will stop at the
        first invalid character.

        For example:

        **QByteArray**  text = **QByteArray** ::fromBase64("UXQgaXMgZ3JlYXQh");
        text.data();            // returns "Qt is great!"
        **QByteArray** ::fromBase64("PHA+SGVsbG8/PC9wPg==", **QByteArray**
        ::Base64Encoding); // returns "<p>Hello?</p>"
            **QByteArray**
        ::fromBase64("PHA-SGVsbG8_PC9wPg==", **QByteArray**
        ::Base64UrlEncoding); // returns "<p>Hello?</p>"

        The algorithm used to decode Base64-encoded data is defined in **RFC
        4648** .

        Returns the decoded data, or, if the `AbortOnBase64DecodingErrors`
        option was passed and the input data was invalid, an empty byte array.

        **Note:** The **fromBase64Encoding** () function is recommended in new
        code.

        This function was introduced in Qt 5.2.

        **See also** **toBase64** () and **fromBase64Encoding** ().
        """
        ...

    @typing.overload
    @staticmethod
    def number(n: float, format: str = ..., precision: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#number

        **[static] QByteArray QByteArray::number(int n , int base = 10)**

        Returns a byte-array representing the whole number **n** as text.

        Returns a byte array containing a string representing **n** , using the
        specified **base** (ten by default). Bases 2 through 36 are supported,
        using letters for digits beyond 9: A is ten, B is eleven and so on.

        Example:

        int n = 63;
            **QByteArray** ::number(n);              // returns "63"
        **QByteArray** ::number(n, 16);          // returns "3f"
        **QByteArray** ::number(n, 16).toUpper();  // returns "3F"

        **Note:** The format of the number is not localized; the default C
        locale is used regardless of the user's locale. Use **QLocale**  to
        perform locale-aware conversions between numbers and strings.

        **See also** **setNum** () and **toInt** ().
        """
        ...

    @typing.overload
    @staticmethod
    def number(n: int, base: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#number-1

        **[static] QByteArray QByteArray::number(uint n , int base = 10)**

        This is an overloaded function.

        **See also** **toUInt** ().
        """
        ...

    @typing.overload
    def setNum(self, n: float, format: str = ..., precision: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#setNum

        **QByteArray &QByteArray::setNum(int n , int base = 10)**

        Represent the whole number **n** as text.

        Sets this byte array to a string representing **n** in base **base**
        (ten by default) and returns a reference to this byte array. Bases 2
        through 36 are supported, using letters for digits beyond 9; A is ten, B
        is eleven and so on.

        Example:

        **QByteArray**  ba;
            int n = 63;
            ba.setNum(n);           // ba ==
        "63"
            ba.setNum(n, 16);       // ba == "3f"

        **Note:** The format of the number is not localized; the default C
        locale is used regardless of the user's locale. Use **QLocale**  to
        perform locale-aware conversions between numbers and strings.

        **See also** **number** () and **toInt** ().
        """
        ...

    @typing.overload
    def setNum(self, n: int, base: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#setNum-1

        **QByteArray &QByteArray::setNum(short n , int base = 10)**

        This is an overloaded function.

        **See also** **toShort** ().
        """
        ...

    def toBase64(self, options: "QByteArray.Base64Option" = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#toBase64

        **[since 5.2] QByteArray QByteArray::toBase64(QByteArray::Base64Options
        options = Base64Encoding) const**

        Returns a copy of the byte array, encoded using the options **options**.

        **QByteArray**  text("Qt is great!");
            text.toBase64();        //
        returns "UXQgaXMgZ3JlYXQh"

            **QByteArray**
        text("<p>Hello?</p>");
            text.toBase64(**QByteArray** ::Base64Encoding
        | **QByteArray** ::OmitTrailingEquals);      // returns
        "PHA+SGVsbG8/PC9wPg"
            text.toBase64(**QByteArray** ::Base64Encoding);
        // returns "PHA+SGVsbG8/PC9wPg=="
            text.toBase64(**QByteArray**
        ::Base64UrlEncoding);                                    // returns
        "PHA-SGVsbG8_PC9wPg=="
            text.toBase64(**QByteArray**
        ::Base64UrlEncoding | **QByteArray** ::OmitTrailingEquals);   // returns
        "PHA-SGVsbG8_PC9wPg"

        The algorithm used to encode Base64-encoded data is defined in **RFC
        4648** .

        This function was introduced in Qt 5.2.

        **See also** **fromBase64** ().
        """
        ...

    def toDouble(self) -> typing.Tuple[float, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toDouble

        **double QByteArray::toDouble(bool * ok = nullptr) const**

        Returns the byte array converted to a `double` value.

        Returns an infinity if the conversion overflows or 0.0 if the conversion
        fails for other reasons (e.g. underflow).

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **QByteArray**  string("1234.56");
            bool ok;
            double a =
        string.toDouble(&ok);   // a == 1234.56, ok == true

            string =
        "1234.56 Volt";
            a = str.toDouble(&ok);             // a == 0, ok ==
        false

        **Warning:** The **QByteArray**  content may only contain valid
        numerical characters which includes the plus/minus sign, the character e
        used in scientific notation, and the decimal point. Including the unit
        or additional characters leads to a conversion error.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        This function ignores leading and trailing whitespace.

        **See also** **number** ().
        """
        ...

    def toFloat(self) -> typing.Tuple[float, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toFloat

        **float QByteArray::toFloat(bool * ok = nullptr) const**

        Returns the byte array converted to a `float` value.

        Returns an infinity if the conversion overflows or 0.0 if the conversion
        fails for other reasons (e.g. underflow).

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **QByteArray**  string("1234.56");
            bool ok;
            float a =
        string.toFloat(&ok);    // a == 1234.56, ok == true

            string =
        "1234.56 Volt";
            a = str.toFloat(&ok);              // a == 0, ok ==
        false

        **Warning:** The **QByteArray**  content may only contain valid
        numerical characters which includes the plus/minus sign, the character e
        used in scientific notation, and the decimal point. Including the unit
        or additional characters leads to a conversion error.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        This function ignores leading and trailing whitespace.

        **See also** **number** ().
        """
        ...

    def toULongLong(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toULongLong

        **qulonglong QByteArray::toULongLong(bool * ok = nullptr, int base = 10)
        const**

        Returns the byte array converted to an `unsigned long long` using base
        **base** , which is ten by default. Bases 0 and 2 through 36 are
        supported, using letters for digits beyond 9; A is ten, B is eleven and
        so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toLongLong(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toLongLong

        **qlonglong QByteArray::toLongLong(bool * ok = nullptr, int base = 10)
        const**

        Returns the byte array converted to a `long long` using base **base** ,
        which is ten by default. Bases 0 and 2 through 36 are supported, using
        letters for digits beyond 9; A is ten, B is eleven and so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toULong(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toULong

        **ulong QByteArray::toULong(bool * ok = nullptr, int base = 10) const**

        Returns the byte array converted to an `unsigned long int` using base
        **base** , which is ten by default. Bases 0 and 2 through 36 are
        supported, using letters for digits beyond 9; A is ten, B is eleven and
        so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toLong(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toLong

        **long QByteArray::toLong(bool * ok = nullptr, int base = 10) const**

        Returns the byte array converted to a `long` int using base **base** ,
        which is ten by default. Bases 0 and 2 through 36 are supported, using
        letters for digits beyond 9; A is ten, B is eleven and so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **QByteArray**  str("FF");
            bool ok;
            long hex = str.toLong(&ok,
        16);   // hex == 255, ok == true
            long dec = str.toLong(&ok, 10);
        // dec == 0, ok == false

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toUInt(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toUInt

        **uint QByteArray::toUInt(bool * ok = nullptr, int base = 10) const**

        Returns the byte array converted to an `unsigned int` using base
        **base** , which is ten by default. Bases 0 and 2 through 36 are
        supported, using letters for digits beyond 9; A is ten, B is eleven and
        so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toInt(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toInt

        **int QByteArray::toInt(bool * ok = nullptr, int base = 10) const**

        Returns the byte array converted to an `int` using base **base** , which
        is ten by default. Bases 0 and 2 through 36 are supported, using letters
        for digits beyond 9; A is ten, B is eleven and so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal (base 16); otherwise, if it begins with "0", it is assumed
        to be octal (base 8); otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **QByteArray**  str("FF");
            bool ok;
            int hex = str.toInt(&ok,
        16);     // hex == 255, ok == true
            int dec = str.toInt(&ok, 10);
        // dec == 0, ok == false

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toUShort(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toUShort

        **ushort QByteArray::toUShort(bool * ok = nullptr, int base = 10)
        const**

        Returns the byte array converted to an `unsigned short` using base
        **base** , which is ten by default. Bases 0 and 2 through 36 are
        supported, using letters for digits beyond 9; A is ten, B is eleven and
        so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal; otherwise, if it begins with "0", it is assumed to be
        octal; otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def toShort(self, base: int = ...) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#toShort

        **short QByteArray::toShort(bool * ok = nullptr, int base = 10) const**

        Returns the byte array converted to a `short` using base **base** ,
        which is ten by default. Bases 0 and 2 through 36 are supported, using
        letters for digits beyond 9; A is ten, B is eleven and so on.

        If **base** is 0, the base is determined automatically using the
        following rules: If the byte array begins with "0x", it is assumed to be
        hexadecimal; otherwise, if it begins with "0", it is assumed to be
        octal; otherwise it is assumed to be decimal.

        Returns 0 if the conversion fails.

        If **ok** is not `nullptr`, failure is reported by setting * **ok** to
        `false`, and success by setting * **ok** to `true`.

        **Note:** The conversion of the number is performed in the default C
        locale, regardless of the user's locale. Use **QLocale**  to perform
        locale-aware conversions between numbers and strings.

        **See also** **number** ().
        """
        ...

    def split(self, sep: bytes) -> typing.List["QByteArray"]:
        """
        https://doc.qt.io/qt-6/qbytearray.html#split

        **QList<QByteArray> QByteArray::split(char sep ) const**

        Splits the byte array into subarrays wherever **sep** occurs, and
        returns the list of those arrays. If **sep** does not match anywhere in
        the byte array, split() returns a single-element list containing this
        byte array.
        """
        ...

    @typing.overload
    def replace(
        self,
        before: typing.Union["QByteArray", bytes, bytearray, memoryview],
        after: typing.Union["QByteArray", bytes, bytearray, memoryview],
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#replace

        **QByteArray &QByteArray::replace(qsizetype pos , qsizetype len ,
        QByteArrayView after )**

        Replaces **len** bytes from index position **pos** with the byte array
        **after** , and returns a reference to this byte array.

        Example:

        **QByteArray**  x("Say yes!");
            **QByteArray**  y("no");
        x.replace(4, 3, y);
            // x == "Say no!"

        **See also** **insert** () and **remove** ().
        """
        ...

    @typing.overload
    def replace(
        self,
        index: int,
        len: int,
        s: typing.Union["QByteArray", bytes, bytearray, memoryview],
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#replace-1

        **QByteArray &QByteArray::replace(qsizetype pos , qsizetype len , const
        char * after , qsizetype alen )**

        This is an overloaded function.

        Replaces **len** bytes from index position **pos** with **alen** bytes
        starting at position **after**. The bytes inserted may include '\\0'
        bytes.
        """
        ...

    def remove(self, index: int, len: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#remove

        **QByteArray &QByteArray::remove(qsizetype pos , qsizetype len )**

        Removes **len** bytes from the array, starting at index position **pos**
        , and returns a reference to the array.

        If **pos** is out of range, nothing happens. If **pos** is valid, but
        **pos** \\+ **len** is larger than the size of the array, the array is
        truncated at position **pos**.

        Example:

        **QByteArray**  ba("Montreal");
            ba.remove(1, 4);
            // ba == "Meal"

        Element removal will preserve the array's capacity and not reduce the
        amount of allocated memory. To shed extra capacity and free as much
        memory as possible, call **squeeze** () after the last change to the
        array's size.

        **See also** **insert** (), **replace** (), and **squeeze** ().
        """
        ...

    @typing.overload
    def insert(
        self, i: int, data: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#insert

        **[since 6.0] QByteArray &QByteArray::insert(qsizetype i ,
        QByteArrayView data )**

        Inserts **data** at index position **i** and returns a reference to this
        byte array.

        Example:

        **QByteArray**  ba("Meal");
            ba.insert(1, **QByteArrayView**
        ("ontr"));
            // ba == "Montreal"

        For large byte arrays, this operation can be slow (**linear time** ),
        because it requires moving all the bytes at indexes **i** and above by
        at least one position further in memory.

        This array grows to accommodate the insertion. If **i** is beyond the
        end of the array, the array is first extended with space characters to
        reach this **i**.

        This function was introduced in Qt 6.0.

        **See also** **append** (), **prepend** (), **replace** (), and
        **remove** ().
        """
        ...

    @typing.overload
    def insert(self, i: int, count: int, c: bytes) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#insert-1

        **QByteArray &QByteArray::insert(qsizetype i , const char * s )**

        Inserts **s** at index position **i** and returns a reference to this
        byte array.

        This array grows to accommodate the insertion. If **i** is beyond the
        end of the array, the array is first extended with space characters to
        reach this **i**.

        The function is equivalent to `insert(i, QByteArrayView(s))`

        **See also** **append** (), **prepend** (), **replace** (), and
        **remove** ().
        """
        ...

    @typing.overload
    def append(
        self, a: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#append

        **QByteArray &QByteArray::append(const QByteArray & ba )**

        Appends the byte array **ba** onto the end of this byte array.

        Example:

        **QByteArray**  x("free");
            **QByteArray**  y("dom");
        x.append(y);
            // x == "freedom"

        This is the same as insert(**size** (), **ba** ).

        Note: **QByteArray**  is an **implicitly shared**  class. Consequently,
        if you append to an empty byte array, then the byte array will just
        share the data held in **ba**. In this case, no copying of data is done,
        taking **constant time** . If a shared instance is modified, it will be
        copied (copy-on-write), taking **linear time** .

        If the byte array being appended to is not empty, a deep copy of the
        data is performed, taking **linear time** .

        The append() function is typically very fast (**constant time** ),
        because **QByteArray**  preallocates extra space at the end of the data,
        so it can grow without reallocating the entire array each time.

        **See also** **operator+=** (), **prepend** (), and **insert** ().
        """
        ...

    @typing.overload
    def append(self, count: int, c: bytes) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#append-1

        **QByteArray &QByteArray::append(char ch )**

        This is an overloaded function.

        Appends the byte **ch** to this byte array.
        """
        ...

    @typing.overload
    def prepend(
        self, a: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#prepend

        **QByteArray &QByteArray::prepend(QByteArrayView ba )**

        Prepends the byte array view **ba** to this byte array and returns a
        reference to this byte array.

        This operation is typically very fast (**constant time** ), because
        **QByteArray**  preallocates extra space at the beginning of the data,
        so it can grow without reallocating the entire array each time.

        Example:

        **QByteArray**  x("ship");
            **QByteArray**  y("air");
        x.prepend(y);
            // x == "airship"

        This is the same as insert(0, **ba** ).

        **See also** **append** () and **insert** ().
        """
        ...

    @typing.overload
    def prepend(self, count: int, c: bytes) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#prepend-1

        **QByteArray &QByteArray::prepend(char ch )**

        This is an overloaded function.

        Prepends the byte **ch** to this byte array.
        """
        ...

    def rightJustified(
        self, width: int, fill: bytes = ..., truncate: bool = ...
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#rightJustified

        **QByteArray QByteArray::rightJustified(qsizetype width , char fill = '
        ', bool truncate = false) const**

        Returns a byte array of size **width** that contains the **fill** byte
        followed by this byte array.

        If **truncate** is false and the size of the byte array is more than
        **width** , then the returned byte array is a copy of this byte array.

        If **truncate** is true and the size of the byte array is more than
        **width** , then the resulting byte array is truncated at position
        **width**.

        Example:

        **QByteArray**  x("apple");
            **QByteArray**  y = x.rightJustified(8,
        '.');    // y == "...apple"

        **See also** **leftJustified** ().
        """
        ...

    def leftJustified(
        self, width: int, fill: bytes = ..., truncate: bool = ...
    ) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#leftJustified

        **QByteArray QByteArray::leftJustified(qsizetype width , char fill = '
        ', bool truncate = false) const**

        Returns a byte array of size **width** that contains this byte array
        padded with the **fill** byte.

        If **truncate** is false and the **size** () of the byte array is more
        than **width** , then the returned byte array is a copy of this byte
        array.

        If **truncate** is true and the **size** () of the byte array is more
        than **width** , then any bytes in a copy of the byte array after
        position **width** are removed, and the copy is returned.

        Example:

        **QByteArray**  x("apple");
            **QByteArray**  y = x.leftJustified(8,
        '.');   // y == "apple..."

        **See also** **rightJustified** ().
        """
        ...

    def simplified(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#simplified

        **QByteArray QByteArray::simplified() const**

        Returns a copy of this byte array that has spacing characters removed
        from the start and end, and in which each sequence of internal spacing
        characters is replaced with a single space.

        The spacing characters are those for which the standard C++ `isspace()`
        function returns `true` in the C locale; these are the ASCII characters
        tabulation '\\t', line feed '\\n', carriage return '\\r', vertical
        tabulation '\\v', form feed '\\f', and space ' '.

        Example:

        **QByteArray**  ba("  lots\\t of\\nwhitespace\\r\\n ");
            ba =
        ba.simplified();
            // ba == "lots of whitespace";

        **See also** **trimmed** (), **QChar::SpecialCharacter** , and **Spacing
        Characters** .
        """
        ...

    def trimmed(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#trimmed

        **QByteArray QByteArray::trimmed() const**

        Returns a copy of this byte array with spacing characters removed from
        the start and end.

        The spacing characters are those for which the standard C++ `isspace()`
        function returns `true` in the C locale; these are the ASCII characters
        tabulation '\\t', line feed '\\n', carriage return '\\r', vertical
        tabulation '\\v', form feed '\\f', and space ' '.

        Example:

        **QByteArray**  ba("  lots\\t of\\nwhitespace\\r\\n ");
            ba =
        ba.trimmed();
            // ba == "lots\\t of\\nwhitespace";

        Unlike **simplified** (), trimmed() leaves internal spacing unchanged.

        **See also** **simplified** (), **QChar::SpecialCharacter** , and
        **Spacing Characters** .
        """
        ...

    def toUpper(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#toUpper

        **QByteArray QByteArray::toUpper() const**

        Returns a copy of the byte array in which each ASCII lowercase letter
        converted to uppercase.

        Example:

        **QByteArray**  x("Qt by THE QT COMPANY");
            **QByteArray**  y =
        x.toUpper();
            // y == "QT BY THE QT COMPANY"

        **See also** **isUpper** (), **toLower** (), and **Character Case** .
        """
        ...

    def toLower(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#toLower

        **QByteArray QByteArray::toLower() const**

        Returns a copy of the byte array in which each ASCII uppercase letter
        converted to lowercase.

        Example:

        **QByteArray**  x("Qt by THE QT COMPANY");
            **QByteArray**  y =
        x.toLower();
            // y == "qt by the qt company"

        **See also** **isLower** (), **toUpper** (), and **Character Case** .
        """
        ...

    def chop(self, n: int) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#chop

        **void QByteArray::chop(qsizetype n )**

        Removes **n** bytes from the end of the byte array.

        If **n** is greater than **size** (), the result is an empty byte array.

        Example:

        **QByteArray**  ba("STARTTLS\\r\\n");
            ba.chop(2);                 //
        ba == "STARTTLS"

        **See also** **truncate** (), **resize** (), and **first** ().
        """
        ...

    def truncate(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#truncate

        **void QByteArray::truncate(qsizetype pos )**

        Truncates the byte array at index position **pos**.

        If **pos** is beyond the end of the array, nothing happens.

        Example:

        **QByteArray**  ba("Stockholm");
            ba.truncate(5);             // ba
        == "Stock"

        **See also** **chop** (), **resize** (), and **first** ().
        """
        ...

    def endsWith(
        self, bv: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#endsWith

        **[since 6.0] bool QByteArray::endsWith(QByteArrayView bv ) const**

        Returns `true` if this byte array ends with the sequence of bytes viewed
        by **bv** ; otherwise returns `false`.

        Example:

        **QByteArray**  url("http://qt-
        project.org/doc/qt-5.0/qtdoc/index.html");
            if
        (url.endsWith(".html"))
                ...

        This function was introduced in Qt 6.0.

        **See also** **startsWith** () and **last** ().
        """
        ...

    def startsWith(
        self, bv: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qbytearray.html#startsWith

        **[since 6.0] bool QByteArray::startsWith(QByteArrayView bv ) const**

        Returns `true` if this byte array starts with the sequence of bytes
        viewed by **bv** ; otherwise returns `false`.

        Example:

        **QByteArray**  url("ftp://ftp.qt-project.org/");
            if
        (url.startsWith("ftp:"))
                ...

        This function was introduced in Qt 6.0.

        **See also** **endsWith** () and **first** ().
        """
        ...

    def last(self, n: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#last

        **[since 6.0] QByteArray QByteArray::last(qsizetype n ) const**

        Returns the last **n** bytes of the byte array.

        **Note:** The behavior is undefined when **n** < 0 or **n** > **size**
        ().

        Example:

        **QByteArray**  x("Pineapple");
            **QByteArray**  y = x.last(5);
        // y == "apple"

        This function was introduced in Qt 6.0.

        **See also** **first** (), **sliced** (), **endsWith** (), **chopped**
        (), **chop** (), and **truncate** ().
        """
        ...

    def first(self, n: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#first

        **[since 6.0] QByteArray QByteArray::first(qsizetype n ) const**

        Returns the first **n** bytes of the byte array.

        **Note:** The behavior is undefined when **n** < 0 or **n** > **size**
        ().

        Example:

        **QByteArray**  x("Pineapple");
            **QByteArray**  y = x.first(4);
        // y == "Pine"

        This function was introduced in Qt 6.0.

        **See also** **last** (), **sliced** (), **startsWith** (), **chopped**
        (), **chop** (), and **truncate** ().
        """
        ...

    def mid(self, index: int, length: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#mid

        **QByteArray QByteArray::mid(qsizetype pos , qsizetype len = -1) const**

        Returns a byte array containing **len** bytes from this byte array,
        starting at position **pos**.

        If you know that **pos** and **len** cannot be out of bounds, use
        **sliced** () instead in new code, because it is faster.

        If **len** is -1 (the default), or **pos** \\+ **len** >= **size** (),
        returns a byte array containing all bytes starting at position **pos**
        until the end of the byte array.

        **See also** **first** (), **last** (), **sliced** (), **chopped** (),
        **chop** (), and **truncate** ().
        """
        ...

    def right(self, len: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#right

        **QByteArray QByteArray::right(qsizetype len ) const**

        Returns a byte array that contains the last **len** bytes of this byte
        array.

        If you know that **len** cannot be out of bounds, use **last** ()
        instead in new code, because it is faster.

        The entire byte array is returned if **len** is greater than **size**
        ().

        Returns an empty **QByteArray**  if **len** is smaller than 0.

        **See also** **endsWith** (), **last** (), **first** (), **sliced** (),
        **chopped** (), **chop** (), and **truncate** ().
        """
        ...

    def left(self, len: int) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#left

        **QByteArray QByteArray::left(qsizetype len ) const**

        Returns a byte array that contains the first **len** bytes of this byte
        array.

        If you know that **len** cannot be out of bounds, use **first** ()
        instead in new code, because it is faster.

        The entire byte array is returned if **len** is greater than **size**
        ().

        Returns an empty **QByteArray**  if **len** is smaller than 0.

        **See also** **first** (), **last** (), **startsWith** (), **chopped**
        (), **chop** (), and **truncate** ().
        """
        ...

    @typing.overload
    def count(
        self, bv: typing.Union["QByteArray", bytes, bytearray, memoryview]
    ) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#count

        **[since 6.0] qsizetype QByteArray::count(QByteArrayView bv ) const**

        Returns the number of (potentially overlapping) occurrences of the
        sequence of bytes viewed by **bv** in this byte array.

        This function was introduced in Qt 6.0.

        **See also** **contains** () and **indexOf** ().
        """
        ...

    @typing.overload
    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#count-1

        **qsizetype QByteArray::count(char ch ) const**

        This is an overloaded function.

        Returns the number of occurrences of byte **ch** in the byte array.

        **See also** **contains** () and **indexOf** ().
        """
        ...

    def lastIndexOf(
        self,
        bv: typing.Union["QByteArray", bytes, bytearray, memoryview],
        from_: int = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#lastIndexOf

        **[since 6.0] qsizetype QByteArray::lastIndexOf(QByteArrayView bv ,
        qsizetype from ) const**

        Returns the index position of the start of the last occurrence of the
        sequence of bytes viewed by **bv** in this byte array, searching
        backward from index position **from**. If **from** is -1, the search
        starts at the last character; if **from** is -2, at the next to last
        character and so on. Returns -1 if no match is found.

        Example:

        **QByteArray**  x("crazy azimuths");
            **QByteArrayView**  y("az");
        x.lastIndexOf(y);           // returns 6
            x.lastIndexOf(y, 6);
        // returns 6
            x.lastIndexOf(y, 5);        // returns 2
        x.lastIndexOf(y, 1);        // returns -1

        **Note:** When searching for a 0-length **bv** , the match at the end of
        the data is excluded from the search by a negative **from** , even
        though `-1` is normally thought of as searching from the end of the byte
        array: the match at the end is **after** the last character, so it is
        excluded. To include such a final empty match, either give a positive
        value for **from** or omit the **from** parameter entirely.

        This function was introduced in Qt 6.0.

        **See also** **indexOf** (), **contains** (), and **count** ().
        """
        ...

    def indexOf(
        self,
        bv: typing.Union["QByteArray", bytes, bytearray, memoryview],
        from_: int = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qbytearray.html#indexOf

        **[since 6.0] qsizetype QByteArray::indexOf(QByteArrayView bv ,
        qsizetype from = 0) const**

        Returns the index position of the start of the first occurrence of the
        sequence of bytes viewed by **bv** in this byte array, searching forward
        from index position **from**. Returns -1 if no match is found.

        Example:

        **QByteArray**  x("sticky question");
            **QByteArrayView**  y("sti");
        x.indexOf(y);               // returns 0
            x.indexOf(y, 1);
        // returns 10
            x.indexOf(y, 10);           // returns 10
        x.indexOf(y, 11);           // returns -1

        This function was introduced in Qt 6.0.

        **See also** **lastIndexOf** (), **contains** (), and **count** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#clear

        **void QByteArray::clear()**

        Clears the contents of the byte array and makes it null.

        **See also** **resize** () and **isNull** ().
        """
        ...

    def fill(self, c: bytes, size: int = ...) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qbytearray.html#fill

        **QByteArray &QByteArray::fill(char ch , qsizetype size = -1)**

        Sets every byte in the byte array to **ch**. If **size** is different
        from -1 (the default), the byte array is resized to size **size**
        beforehand.

        Example:

        **QByteArray**  ba("Istambul");
            ba.fill('o');
            // ba ==
        "oooooooo"

            ba.fill('X', 2);
            // ba == "XX"

        **See also** **resize** ().
        """
        ...

    def resize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qbytearray.html#resize

        **void QByteArray::resize(qsizetype size )**

        Sets the size of the byte array to **size** bytes.

        If **size** is greater than the current size, the byte array is extended
        to make it **size** bytes with the extra bytes added to the end. The new
        bytes are uninitialized.

        If **size** is less than the current size, bytes beyond position
        **size** are excluded from the byte array.

        **Note:** While resize() will grow the capacity if needed, it never
        shrinks capacity. To shed excess capacity, use **squeeze** ().

        **See also** **size** (), **truncate** (), and **squeeze** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtSensors import *


class QLightFilter(QSensorFilter):
    """
    https://doc.qt.io/qt-6/qlightfilter.html

    **Detailed Description**

    The only difference is that the **filter** () method features a pointer to
    **QLightReading**  instead of **QSensorReading** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QLightFilter") -> None:
        ...

    def filter(self, reading: QLightReading) -> bool:
        """
        https://doc.qt.io/qt-6/qlightfilter.html#filter

        **[pure virtual] bool QLightFilter::filter(QLightReading * reading )**

        Called when **reading** changes. Returns false to prevent the reading
        from propagating.

        **See also** **QSensorFilter::filter** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QAxContainer import *


class QAxObject(QAxBaseObject, QAxBase):
    """
    https://doc.qt.io/qt-6/qaxobject.html

    **Detailed Description**

    A QAxObject can be instantiated as an empty object, with the name of the COM
    object it should wrap, or with a pointer to the IUnknown that represents an
    existing COM object. If the COM object implements the `IDispatch` interface,
    the properties, methods and events of that object become available as Qt
    properties, slots and signals. The base class, **QAxBase** , provides an API
    to access the COM object directly through the IUnknown pointer.

    QAxObject is a **QObject**  and can be used as such, e.g. it can be
    organized in an object hierarchy, receive events and connect to signals and
    slots.

    QAxObject also inherits most of its ActiveX-related functionality from
    **QAxBase** , notably **dynamicCall** () and **querySubObject** ().

    **Warning:** You can subclass QAxObject, but you cannot use the **Q_OBJECT**
    macro in the subclass (the generated moc-file will not compile), so you
    cannot add further signals, slots or properties. This limitation is due to
    the metaobject information generated in runtime. To work around this
    problem, aggregate the QAxObject as a member of the **QObject**  subclass.

    **See also** **QAxBase** , **QAxWidget** , **QAxScript** , and **ActiveQt
    Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qaxobject.html#QAxObject

        **QAxObject::QAxObject(QObject * parent = nullptr)**

        Creates an empty COM object and propagates **parent** to the **QObject**
        constructor. To initialize the object, call setControl().

        **See also** **setControl()** .
        """
        ...

    @typing.overload
    def __init__(self, a0: str, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qaxobject.html#QAxObject-1

        **QAxObject::QAxObject(const QString & c , QObject * parent = nullptr)**

        Creates a QAxObject that wraps the COM object **c**. **parent** is
        propagated to the **QObject**  constructor.

        **See also** **setControl()** .
        """
        ...

    def connectNotify(self, a0: QtCore.QMetaMethod) -> None:
        """
        https://doc.qt.io/qt-6/qaxobject.html#connectNotify

        **[override virtual protected] void QAxObject::connectNotify(const
        QMetaMethod & signal )**

        Reimplements: **QObject::connectNotify** (const QMetaMethod &signal).
        """
        ...

    def doVerb(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxobject.html#doVerb

        **bool QAxObject::doVerb(const QString & verb )**

        Requests the COM object to perform the action **verb**. The possible
        verbs are returned by **verbs** ().

        The function returns true if the object could perform the action,
        otherwise returns false.
        """
        ...

    def clear(self) -> None:
        ...

    def resetControl(self) -> None:
        ...

    def setControl(self, c: str) -> bool:
        ...

    def control(self) -> str:
        ...

    def setClassContext(self, classContext: int) -> None:
        ...

    def classContext(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QIcon(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qicon.html

    **Detailed Description**

    A QIcon can generate smaller, larger, active, and disabled pixmaps from the
    set of pixmaps it is given. Such pixmaps are used by Qt widgets to show an
    icon representing a particular action.

    The simplest use of QIcon is to create one from a **QPixmap**  file or
    resource, and then use it, allowing Qt to work out all the required icon
    styles and sizes. For example:

    **QToolButton**  *button = new **QToolButton** ;
    button->setIcon(**QIcon** ("open.xpm"));

    To undo a QIcon, simply set a null icon in its place:

    button->setIcon(**QIcon** ());

    Use the **QImageReader::supportedImageFormats** () and
    **QImageWriter::supportedImageFormats** () functions to retrieve a complete
    list of the supported file formats.

    When you retrieve a pixmap using pixmap(**QSize** , Mode, State), and no
    pixmap for this given size, mode and state has been added with **addFile**
    () or **addPixmap** (), then QIcon will generate one on the fly. This pixmap
    generation happens in a **QIconEngine** . The default engine scales pixmaps
    down if required, but never up, and it uses the current style to calculate a
    disabled appearance. By using custom icon engines, you can customize every
    aspect of generated icons. With **QIconEnginePlugin**  it is possible to
    register different icon engines for different file suffixes, making it
    possible for third parties to provide additional icon engines to those
    included with Qt.

    **Note:** Since Qt 4.2, an icon engine that supports SVG is included.

    **Making Classes that Use QIcon**

    If you write your own widgets that have an option to set a small pixmap,
    consider allowing a QIcon to be set for that pixmap. The Qt class
    **QToolButton**  is an example of such a widget.

    Provide a method to set a QIcon, and when you draw the icon, choose
    whichever pixmap is appropriate for the current state of your widget. For
    example:

    void MyWidget::drawIcon(**QPainter**  *painter, **QPoint**  pos)
        {
    **QPixmap**  pixmap = icon.pixmap(**QSize** (22, 22),
    isEnabled() ? **QIcon** ::Normal
    : **QIcon** ::Disabled,
                                           isChecked() ?
    **QIcon** ::On
                                                       :
    **QIcon** ::Off);
            painter->drawPixmap(pos, pixmap);
        }

    You might also make use of the `Active` mode, perhaps making your widget
    `Active` when the mouse is over the widget (see **QWidget::enterEvent** ()),
    while the mouse is pressed pending the release that will activate the
    function, or when it is the currently selected item. If the widget can be
    toggled, the "On" mode might be used to draw a different icon.

    ![QIcon](images/icon.png)

    **Note:** QIcon needs a **QGuiApplication**  instance before the icon is
    created.

    **High DPI Icons**

    There are two ways that QIcon supports **high DPI**  icons: via **addFile**
    () and **fromTheme** ().

    **addFile** () is useful if you have your own custom directory structure and
    do not need to use the **freedesktop.org Icon Theme Specification** . Icons
    created via this approach use Qt's **"@nx" high DPI syntax** .

    Using **fromTheme** () is necessary if you plan on following the Icon Theme
    Specification. To make QIcon use the high DPI version of an image, add an
    additional entry to the appropriate `index.theme` file:

    [Icon Theme]
        Name=Test
        Comment=Test Theme
    Directories=32x32/actions,32x32@2/actions

        [32x32/actions]
    Size=32
        Context=Actions
        Type=Fixed

        # High DPI version of
    the entry above.
        [32x32@2/actions]
        Size=32
        Scale=2
    Type=Fixed

    Your icon theme directory would then look something like this:

    ├── 32x32
        │   └── actions
        │       └── appointment-new.png
        ├──
    32x32@2
        │   └── actions
        │       └── appointment-new.png
        └──
    index.theme

    **See also** **GUI Design Handbook: Iconic Label**  and **Icons Example** .
    """

    class State(enum.Enum):
        On: QIcon = ...
        Off: QIcon = ...

    class Mode(enum.Enum):
        Normal: QIcon = ...
        Disabled: QIcon = ...
        Active: QIcon = ...
        Selected: QIcon = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon

        **QIcon::QIcon()**

        Constructs a null icon.
        """
        ...

    @typing.overload
    def __init__(self, pixmap: QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon-1

        **QIcon::QIcon(const QPixmap & pixmap )**

        Constructs an icon from a **pixmap**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QIcon") -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon-2

        **QIcon::QIcon(const QIcon & other )**

        Constructs a copy of **other**. This is very fast.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon-3

        **QIcon::QIcon(QIcon && other )**

        Move-constructs a QIcon instance, making it point to the same object
        that **other** was pointing to.
        """
        ...

    @typing.overload
    def __init__(self, engine: "QIconEngine") -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon-4

        **QIcon::QIcon(const QString & fileName )**

        Constructs an icon from the file with the given **fileName**. The file
        will be loaded on demand.

        If **fileName** contains a relative path (e.g. the filename only) the
        relevant file must be found relative to the runtime working directory.

        The file name can refer to an actual file on disk or to one of the
        application's embedded resources. See the **Resource System**  overview
        for details on how to embed images and other resource files in the
        application's executable.

        Use the **QImageReader::supportedImageFormats** () and
        **QImageWriter::supportedImageFormats** () functions to retrieve a
        complete list of the supported file formats.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#QIcon-5

        **QIcon::QIcon(QIconEngine * engine )**

        Creates an icon with a specific icon **engine**. The icon takes
        ownership of the engine.
        """
        ...

    @staticmethod
    def setFallbackThemeName(name: str) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#setFallbackThemeName

        **[static, since 5.12] void QIcon::setFallbackThemeName(const QString &
        name )**

        Sets the fallback icon theme to **name**.

        The **name** should correspond to a directory name in the
        themeSearchPath() containing an index.theme file describing its
        contents.

        **Note:** This should be done before creating **QGuiApplication** , to
        ensure correct initialization.

        This function was introduced in Qt 5.12.

        **See also** **fallbackThemeName** (), **themeSearchPaths** (), and
        **themeName** ().
        """
        ...

    @staticmethod
    def fallbackThemeName() -> str:
        """
        https://doc.qt.io/qt-6/qicon.html#fallbackThemeName

        **[static, since 5.12] QString QIcon::fallbackThemeName()**

        Returns the name of the fallback icon theme.

        On X11, if not set, the fallback icon theme depends on your desktop
        settings. On other platforms it is not set by default.

        This function was introduced in Qt 5.12.

        **See also** **setFallbackThemeName** () and **themeName** ().
        """
        ...

    @staticmethod
    def setFallbackSearchPaths(paths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#setFallbackSearchPaths

        **[static, since 5.11] void QIcon::setFallbackSearchPaths(const
        QStringList & paths )**

        Sets the fallback search paths for icons to **paths**.

        **Note:** To add some path without replacing existing ones:

        **QIcon** ::setFallbackSearchPaths(**QIcon** ::fallbackSearchPaths() <<
        "my/search/path");

        This function was introduced in Qt 5.11.

        **See also** **fallbackSearchPaths** () and **setThemeSearchPaths** ().
        """
        ...

    @staticmethod
    def fallbackSearchPaths() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qicon.html#fallbackSearchPaths

        **[static, since 5.11] QStringList QIcon::fallbackSearchPaths()**

        Returns the fallback search paths for icons.

        The default value will depend on the platform.

        This function was introduced in Qt 5.11.

        **See also** **setFallbackSearchPaths** () and **themeSearchPaths** ().
        """
        ...

    def isMask(self) -> bool:
        """
        https://doc.qt.io/qt-6/qicon.html#isMask

        **[since 5.6] bool QIcon::isMask() const**

        Returns `true` if this icon has been marked as a mask image. Certain
        platforms render mask icons differently (for example, menu icons on
        macOS).

        This function was introduced in Qt 5.6.

        **See also** **setIsMask** ().
        """
        ...

    def setIsMask(self, isMask: bool) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#setIsMask

        **[since 5.6] void QIcon::setIsMask(bool isMask )**

        Indicate that this icon is a mask image(boolean **isMask** ), and hence
        can potentially be modified based on where it's displayed.

        This function was introduced in Qt 5.6.

        **See also** **isMask** ().
        """
        ...

    def swap(self, other: "QIcon") -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#swap

        **void QIcon::swap(QIcon & other )**

        Swaps icon **other** with this icon. This operation is very fast and
        never fails.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qicon.html#name

        **QString QIcon::name() const**

        Returns the name used to create the icon, if available.

        Depending on the way the icon was created, it may have an associated
        name. This is the case for icons created with **fromTheme** () or icons
        using a **QIconEngine**  which supports the QIconEngine::IconNameHook.

        **See also** **fromTheme** () and **QIconEngine** .
        """
        ...

    @staticmethod
    def setThemeName(path: str) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#setThemeName

        **[static] void QIcon::setThemeName(const QString & name )**

        Sets the current icon theme to **name**.

        The **name** should correspond to a directory name in the
        themeSearchPath() containing an index.theme file describing its
        contents.

        **See also** **themeSearchPaths** () and **themeName** ().
        """
        ...

    @staticmethod
    def themeName() -> str:
        """
        https://doc.qt.io/qt-6/qicon.html#themeName

        **[static] QString QIcon::themeName()**

        Returns the name of the current icon theme.

        On X11, the current icon theme depends on your desktop settings. On
        other platforms it is not set by default.

        **See also** **setThemeName** (), **themeSearchPaths** (), **fromTheme**
        (), and **hasThemeIcon** ().
        """
        ...

    @staticmethod
    def setThemeSearchPaths(searchpath: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#setThemeSearchPaths

        **[static] void QIcon::setThemeSearchPaths(const QStringList & paths )**

        Sets the search paths for icon themes to **paths**.

        **See also** **themeSearchPaths** (), **fromTheme** (), and
        **setThemeName** ().
        """
        ...

    @staticmethod
    def themeSearchPaths() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qicon.html#themeSearchPaths

        **[static] QStringList QIcon::themeSearchPaths()**

        Returns the search paths for icon themes.

        The default value will depend on the platform:

        On X11, the search path will use the XDG_DATA_DIRS environment variable
        if available.

        By default all platforms will have the resource directory `:\\icons` as a
        fallback. You can use "rcc -project" to generate a resource file from
        your icon theme.

        **See also** **setThemeSearchPaths** (), **fromTheme** (), and
        **setThemeName** ().
        """
        ...

    @staticmethod
    def hasThemeIcon(name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qicon.html#hasThemeIcon

        **[static] bool QIcon::hasThemeIcon(const QString & name )**

        Returns `true` if there is an icon available for **name** in the current
        icon theme, otherwise returns `false`.

        **See also** **themeSearchPaths** (), **fromTheme** (), and
        **setThemeName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromTheme(name: str) -> "QIcon":
        """
        https://doc.qt.io/qt-6/qicon.html#fromTheme

        **[static] QIcon QIcon::fromTheme(const QString & name )**

        Returns the **QIcon**  corresponding to **name** in the current icon
        theme.

        The latest version of the freedesktop icon specification and naming
        specification can be obtained here:

        * <http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-
        latest.html>
          * <http://standards.freedesktop.org/icon-naming-
        spec/icon-naming-spec-latest.html>

        To fetch an icon from the current icon theme:

        **QIcon**  undoicon = **QIcon** ::fromTheme("edit-undo");

        **Note:** By default, only X11 will support themed icons. In order to
        use themed icons on Mac and Windows, you will have to bundle a compliant
        theme in one of your **themeSearchPaths** () and set the appropriate
        **themeName** ().

        **Note:** Qt will make use of GTK's icon-theme.cache if present to speed
        up the lookup. These caches can be generated using gtk-update-icon-
        cache: <https://developer.gnome.org/gtk3/stable/gtk-update-icon-
        cache.html>.

        **Note:** If an icon can't be found in the current theme, then it will
        be searched in **fallbackSearchPaths** () as an unthemed icon.

        **See also** **themeName** (), **setThemeName** (), **themeSearchPaths**
        (), and **fallbackSearchPaths** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromTheme(name: str, fallback: "QIcon") -> "QIcon":
        """
        https://doc.qt.io/qt-6/qicon.html#fromTheme-1

        **[static] QIcon QIcon::fromTheme(const QString & name , const QIcon &
        fallback )**

        This is an overloaded function.

        Returns the **QIcon**  corresponding to **name** in the current icon
        theme. If no such icon is found in the current theme **fallback** is
        returned instead.

        If you want to provide a guaranteed fallback for platforms that do not
        support theme icons, you can use the second argument:

        **QIcon**  undoicon = **QIcon** ::fromTheme("edit-undo", **QIcon**
        (":/undo.png"));
        """
        ...

    def cacheKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qicon.html#cacheKey

        **qint64 QIcon::cacheKey() const**

        Returns a number that identifies the contents of this **QIcon**  object.
        Distinct **QIcon**  objects can have the same key if they refer to the
        same contents.

        The cacheKey() will change when the icon is altered via **addPixmap** ()
        or **addFile** ().

        Cache keys are mostly useful in conjunction with caching.

        **See also** **QPixmap::cacheKey** ().
        """
        ...

    def addFile(
        self,
        fileName: str,
        size: QtCore.QSize = ...,
        mode: "QIcon.Mode" = ...,
        state: "QIcon.State" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#addFile

        **void QIcon::addFile(const QString & fileName , const QSize & size =
        QSize(), QIcon::Mode mode = Normal, QIcon::State state = Off)**

        Adds an image from the file with the given **fileName** to the icon, as
        a specialization for **size** , **mode** and **state**. The file will be
        loaded on demand. Note: custom icon engines are free to ignore
        additionally added pixmaps.

        If **fileName** contains a relative path (e.g. the filename only) the
        relevant file must be found relative to the runtime working directory.

        The file name can refer to an actual file on disk or to one of the
        application's embedded resources. See the **Resource System**  overview
        for details on how to embed images and other resource files in the
        application's executable.

        Use the **QImageReader::supportedImageFormats** () and
        **QImageWriter::supportedImageFormats** () functions to retrieve a
        complete list of the supported file formats.

        If a high resolution version of the image exists (identified by the
        suffix `@2x` on the base name), it is automatically loaded and added
        with the **device pixel ratio** set to a value of 2. This can be
        disabled by setting the environment variable
        `QT_HIGHDPI_DISABLE_2X_IMAGE_LOADING` (see **QImageReader** ).

        **Note:** When you add a non-empty filename to a **QIcon** , the icon
        becomes non-null, even if the file doesn't exist or points to a corrupt
        file.

        **See also** **addPixmap** () and **QPixmap::devicePixelRatio** ().
        """
        ...

    def addPixmap(
        self, pixmap: QPixmap, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#addPixmap

        **void QIcon::addPixmap(const QPixmap & pixmap , QIcon::Mode mode =
        Normal, QIcon::State state = Off)**

        Adds **pixmap** to the icon, as a specialization for **mode** and
        **state**.

        Custom icon engines are free to ignore additionally added pixmaps.

        **See also** **addFile** ().
        """
        ...

    def isDetached(self) -> bool:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qicon.html#isNull

        **bool QIcon::isNull() const**

        Returns `true` if the icon is empty; otherwise returns `false`.

        An icon is empty if it has neither a pixmap nor a filename.

        Note: Even a non-null icon might not be able to create valid pixmaps,
        eg. if the file does not exist or cannot be read.
        """
        ...

    @typing.overload
    def paint(
        self,
        painter: "QPainter",
        rect: QtCore.QRect,
        alignment: QtCore.Qt.AlignmentFlag = ...,
        mode: "QIcon.Mode" = ...,
        state: "QIcon.State" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#paint

        **void QIcon::paint(QPainter * painter , const QRect & rect ,
        Qt::Alignment alignment = Qt::AlignCenter, QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        Uses the **painter** to paint the icon with specified **alignment** ,
        required **mode** , and **state** into the rectangle **rect**.

        **See also** **actualSize** () and **pixmap** ().
        """
        ...

    @typing.overload
    def paint(
        self,
        painter: "QPainter",
        x: int,
        y: int,
        w: int,
        h: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
        mode: "QIcon.Mode" = ...,
        state: "QIcon.State" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qicon.html#paint-1

        **void QIcon::paint(QPainter * painter , int x , int y , int w , int h ,
        Qt::Alignment alignment = Qt::AlignCenter, QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        This is an overloaded function.

        Paints the icon into the rectangle **QRect** ( **x** , **y** , **w** ,
        **h** ).
        """
        ...

    def availableSizes(
        self, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> typing.List[QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qicon.html#availableSizes

        **QList<QSize> QIcon::availableSizes(QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        Returns a list of available icon sizes for the specified **mode** and
        **state**.
        """
        ...

    def actualSize(
        self, size: QtCore.QSize, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qicon.html#actualSize

        **QSize QIcon::actualSize(const QSize & size , QIcon::Mode mode =
        Normal, QIcon::State state = Off) const**

        Returns the actual size of the icon for the requested **size** ,
        **mode** , and **state**. The result might be smaller than requested,
        but never larger. The returned size is in device-independent pixels
        (This is relevant for high-dpi pixmaps.)

        **See also** **pixmap** () and **paint** ().
        """
        ...

    @typing.overload
    def pixmap(
        self,
        size: QtCore.QSize,
        devicePixelRatio: float,
        mode: "QIcon.Mode" = ...,
        state: "QIcon.State" = ...,
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qicon.html#pixmap

        **QPixmap QIcon::pixmap(const QSize & size , QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        Returns a pixmap with the requested **size** , **mode** , and **state**
        , generating one if necessary. The pixmap might be smaller than
        requested, but never larger, unless the device-pixel ratio of the
        returned pixmap is larger than 1.

        **See also** **actualSize** () and **paint** ().
        """
        ...

    @typing.overload
    def pixmap(
        self, size: QtCore.QSize, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qicon.html#pixmap-1

        **QPixmap QIcon::pixmap(int w , int h , QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        This is an overloaded function.

        Returns a pixmap of size **QSize** ( **w** , **h** ). The pixmap might
        be smaller than requested, but never larger, unless the device-pixel
        ratio of the returned pixmap is larger than 1.
        """
        ...

    @typing.overload
    def pixmap(
        self, w: int, h: int, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qicon.html#pixmap-2

        **QPixmap QIcon::pixmap(int extent , QIcon::Mode mode = Normal,
        QIcon::State state = Off) const**

        This is an overloaded function.

        Returns a pixmap of size **QSize** ( **extent** , **extent** ). The
        pixmap might be smaller than requested, but never larger, unless the
        device-pixel ratio of the returned pixmap is larger than 1.
        """
        ...

    @typing.overload
    def pixmap(
        self, extent: int, mode: "QIcon.Mode" = ..., state: "QIcon.State" = ...
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qicon.html#pixmap-3

        **[since 6.0] QPixmap QIcon::pixmap(const QSize & size , qreal
        devicePixelRatio , QIcon::Mode mode = Normal, QIcon::State state = Off)
        const**

        This is an overloaded function.

        Returns a pixmap with the requested **size** , **devicePixelRatio** ,
        **mode** , and **state** , generating one if necessary.

        This function was introduced in Qt 6.0.

        **See also** **actualSize** () and **paint** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QReadLocker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qreadlocker.html

    **Detailed Description**

    The purpose of QReadLocker (and **QWriteLocker** ) is to simplify
    **QReadWriteLock**  locking and unlocking. Locking and unlocking statements
    or in exception handling code is error-prone and difficult to debug.
    QReadLocker can be used in such situations to ensure that the state of the
    lock is always well-defined.

    Here's an example that uses QReadLocker to lock and unlock a read-write lock
    for reading:

    **QReadWriteLock**  lock;

        **QByteArray**  readData()
        {
    **QReadLocker**  locker(&lock);
            ...
            return data;
        }

    It is equivalent to the following code:

    **QReadWriteLock**  lock;

        **QByteArray**  readData()
        {
    lock.lockForRead();
            ...
            lock.unlock();
            return data;
    }

    The **QMutexLocker**  documentation shows examples where the use of a locker
    object greatly simplifies programming.

    **See also** **QWriteLocker**  and **QReadWriteLock** .
    """

    def __init__(self, areadWriteLock: QReadWriteLock) -> None:
        """
        https://doc.qt.io/qt-6/qreadlocker.html#QReadLocker

        **QReadLocker::QReadLocker(QReadWriteLock * lock )**

        Constructs a QReadLocker and locks **lock** for reading. The lock will
        be unlocked when the QReadLocker is destroyed. If `lock` is zero,
        QReadLocker does nothing.

        **See also** **QReadWriteLock::lockForRead** ().
        """
        ...

    def __exit__(
        self, type: typing.Any, value: typing.Any, traceback: typing.Any
    ) -> None:
        ...

    def __enter__(self) -> typing.Any:
        ...

    def readWriteLock(self) -> QReadWriteLock:
        """
        https://doc.qt.io/qt-6/qreadlocker.html#readWriteLock

        **QReadWriteLock *QReadLocker::readWriteLock() const**

        Returns a pointer to the read-write lock that was passed to the
        constructor.
        """
        ...

    def relock(self) -> None:
        """
        https://doc.qt.io/qt-6/qreadlocker.html#relock

        **void QReadLocker::relock()**

        Relocks an unlocked lock.

        **See also** **unlock** ().
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qreadlocker.html#unlock

        **void QReadLocker::unlock()**

        Unlocks the lock associated with this locker.

        **See also** **QReadWriteLock::unlock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNfc import *


class QNdefFilter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qndeffilter.html

    **Detailed Description**

    The QNdefFilter encapsulates the structure of an NDEF message and is used
    for matching messages that have a particular structure.

    The following filter matches NDEF messages that contain a single smart
    poster record:

    **QNdefFilter**  filter;
        filter.append(**QNdefRecord** ::NfcRtd, "Sp");

    The following filter matches NDEF messages that contain a URI, a localized
    piece of text and an optional JPEG image. The order of the records must be
    in the order specified:

    **QNdefFilter**  filter;
        filter.setOrderMatch(true);
    filter.appendRecord(**QNdefRecord** ::NfcRtd, "U");
    filter.appendRecord<**QNdefNfcTextRecord** >();
    filter.appendRecord(**QNdefRecord** ::Mime, "image/jpeg", 0, 1);

    The **match** () method can be used to check if a message matches the
    filter.

    **Matching Algorithms**

    The filter behavior depends on the value of **orderMatch** () parameter.

    **Note:** In the discussion below we will consider the filter records to be
    equal if their `typeNameFormat` and `type` parameters match. Joining two
    records means adding their `minimum` and `maximum` values, respectively.

    **Unordered Matching**

    If the record order is not taken into account, all the equal records in the
    filter can be joined. The resulting filter will contain only unique records,
    each with the updated `minimum` and `maximum` value.

    Consider the following example:

    **QNdefFilter**  filter;
        filter.appendRecord<**QNdefNfcTextRecord** >(0,
    1);
        filter.appendRecord<**QNdefNfcTextRecord** >(0, 1);
    filter.appendRecord(**QNdefRecord** ::Mime, "", 1, 1);
    filter.appendRecord<**QNdefNfcTextRecord** >(1, 1);
    filter.setOrderMatch(false);

    With the unordered matching, the filter will be simplified to the following:

    **QNdefFilter**  filter;
        filter.appendRecord<**QNdefNfcTextRecord** >(1,
    3);
        filter.appendRecord(**QNdefRecord** ::Mime, "", 1, 1);
    filter.setOrderMatch(false);

    Once the filter contains only the unique records, the matching algorithm
    iterates through the message and calculates the actual amount of records of
    each type. If all the actual amounts fit in the corresponding [minimum,
    maximum] ranges, the matching algorithm returns `true`.

    **Ordered Matching**

    If the record order is important, a different approach is applied. In this
    case the equal records can't be simply joined together. However, the
    consecutive equal records can still be joined. Then, the matching algorithm
    iterates through the message, this time also taking the positions of the
    records into account.

    **Handling Empty Type in Filter Record**

    It's possible to add a filter record with an empty `type`. In this case the
    empty type will act as a wildcard for any type.

    For example, the filter can be defined as follows:

    **QNdefFilter**  filter;
        filter.addRecord(**QNdefRecord** ::Mime, "", 1,
    1);

    This filter specifies that the message must contain exactly one NDEF record
    with **Mime**  **typeNameFormat** (), and any **type** ().

    **Handling Extra Records in the Message**

    If the message contains some records that do not match **any** record in the
    filter, the matching algorithm will return `false`.

    **Filter Examples**

    In the table below, each filter record is specified by the following
    parameters (in the given order):

    * `typeNameFormat` \\- contains the **typeNameFormat** () of the record.
      *
    `type` \\- contains the **type** () of the record.
      * `minimum` \\- contains
    the minimum amount of occurrences of the record in the message.
      *
    `maximum` \\- contains the maximum amount of occurrences of the record in the
    message.

    The filter contains multiple records.

    The message consists of multiple **QNdefRecord** s. In the table below, only
    the **typeNameFormat** () and **type** () of each record will be shown,
    because the other parameters do not matter for filtering.

    FilterMessageMatch ResultComment
    Empty filterEmpty messageMatch
    Empty
    filterNon-empty messageNo match
    Non-empty filterEmpty messageNo match
    [(**QNdefRecord::NfcRtd** , "T", 1, 2), (**QNdefRecord::Mime** , "", 1, 1),
    (**QNdefRecord::Empty** , "", 0, 100)][(**QNdefRecord::Mime** ,
    "image/jpeg"), (**QNdefRecord::Empty** , ""), (**QNdefRecord::NfcRtd** ,
    "T"), (**QNdefRecord::Empty** , ""), (**QNdefRecord::NfcRtd** ,
    "T")]Unordered: matchOrdered filter does not match because the message must
    start with a **QNdefRecord::NfcRtd**  record, but it starts with
    **QNdefRecord::Mime** .
    Ordered: no match
    [(**QNdefRecord::NfcRtd** ,
    "T", 0, 2), (**QNdefRecord::Mime** , "", 1, 1), (**QNdefRecord::NfcRtd** ,
    "T", 1, 1)][(**QNdefRecord::NfcRtd** , "T"), (**QNdefRecord::NfcRtd** ,
    "T"), (**QNdefRecord::Mime** , "image/jpeg")]Unordered: matchOrdered filter
    does not match because an **QNdefRecord::NfcRtd**  record is expected after
    **QNdefRecord::Mime** , but the message does not have it.
    Ordered: no
    match
    [(**QNdefRecord::NfcRtd** , "T", 0, 2), (**QNdefRecord::NfcRtd** ,
    "T", 1, 1), (**QNdefRecord::Mime** , "", 1, 1)][(**QNdefRecord::NfcRtd** ,
    "T"), (**QNdefRecord::Mime** , "image/jpeg")]Unordered: matchBoth cases
    match because the message contains the required minimum of records in the
    correct order.
    Ordered: match
    """

    class Record(PyQt6.sip.simplewrapper):
        maximum: int = ...
        minimum: int = ...
        type: QtCore = ...
        typeNameFormat = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QNdefFilter.Record") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#QNdefFilter

        **QNdefFilter::QNdefFilter()**

        Constructs a new NDEF filter.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNdefFilter") -> None:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#QNdefFilter-1

        **QNdefFilter::QNdefFilter(const QNdefFilter & other )**

        Constructs a new NDEF filter that is a copy of **other**.
        """
        ...

    def match(self, message: "QNdefMessage") -> bool:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#match

        **[since 6.2] bool QNdefFilter::match(const QNdefMessage & message )
        const**

        Returns `true` if the **message** matches the given filter. Otherwise
        returns `false`.

        See **Matching Algorithms**  for more detailed explanation of matching.

        This function was introduced in Qt 6.2.
        """
        ...

    def recordAt(self, i: int) -> "QNdefFilter.Record":
        """
        https://doc.qt.io/qt-6/qndeffilter.html#recordAt

        **QNdefFilter::Record QNdefFilter::recordAt(qsizetype i ) const**

        Returns the NDEF record at index **i**.

        **i** must be a valid index (i.e. 0 <= i < **recordCount** ()).

        **See also** **recordCount** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def recordCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#recordCount

        **qsizetype QNdefFilter::recordCount() const**

        Returns the number of NDEF records in the filter.
        """
        ...

    @typing.overload
    def appendRecord(self, record: "QNdefFilter.Record") -> bool:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#appendRecord

        **template <typename T> bool QNdefFilter::appendRecord(unsigned int min
        = 1, unsigned int max = 1)**

        Appends a record matching the template parameter to the NDEF filter. The
        record must occur between **min** and **max** times in the NDEF message.

        Returns `true` if the record was appended successfully. Otherwise
        returns `false`.
        """
        ...

    @typing.overload
    def appendRecord(
        self,
        typeNameFormat: "QNdefRecord.TypeNameFormat",
        type: QtCore.QByteArray,
        min: int = ...,
        max: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#appendRecord-1

        **bool QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat
        typeNameFormat , const QByteArray & type , unsigned int min = 1,
        unsigned int max = 1)**

        Appends a record with type name format **typeNameFormat** and type
        **type** to the NDEF filter. The record must occur between **min** and
        **max** times in the NDEF message.

        Returns `true` if the record was appended successfully. Otherwise
        returns `false`.
        """
        ...

    def orderMatch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#orderMatch

        **bool QNdefFilter::orderMatch() const**

        Returns `true` if the filter takes NDEF record order into account when
        matching. Otherwise returns `false`.

        **See also** **setOrderMatch** ().
        """
        ...

    def setOrderMatch(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#setOrderMatch

        **void QNdefFilter::setOrderMatch(bool on )**

        Sets the ordering requirements of the filter. If **on** is `true`, the
        filter will only match if the order of records in the filter matches the
        order of the records in the NDEF message. If **on** is `false`, the
        order of the records is not taken into account when matching.

        By default record order is not taken into account.

        **See also** **orderMatch** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qndeffilter.html#clear

        **void QNdefFilter::clear()**

        Clears the filter.
        """
        ...
